@@ -361,7 +361,7 @@ lav_model <- function(lavpartable = NULL,                          # nolint
     if (composites) {
       mm.in.group <- 1:nmat[g] + cumsum(c(0L, nmat))[g]
       tmp.glist[mm.in.group] <-
-        setVarianceComposites.LISREL(tmp.glist[mm.in.group])
+        lav_lisrel_composites_variances(tmp.glist[mm.in.group])
     }
   } # g
 
@@ -388,7 +388,7 @@ lav_model <- function(lavpartable = NULL,                          # nolint
   }
 
   # which free parameters are observed variances?
-  ov.names <- vnames(lavpartable, "ov")
+  ov.names <- lav_partable_vnames(lavpartable, "ov")
   x.free.var.idx <- lavpartable$free[lavpartable$free &
     # !duplicated(lavpartable$free) &
     lavpartable$lhs %in% ov.names &
@@ -402,8 +402,8 @@ lav_model <- function(lavpartable = NULL,                          # nolint
     # we should also add splitted-y names (x) to lv.names
     # FIXME: make this work for multiple work multilevel
     level.values <- lav_partable_level_values(lavpartable)
-    ovx1 <- lavNames(lavpartable, "ov.x", level = level.values[1])
-    ovx2 <- lavNames(lavpartable, "ov.x", level = level.values[2])
+    ovx1 <- lav_object_vnames(lavpartable, "ov.x", level = level.values[1])
+    ovx2 <- lav_object_vnames(lavpartable, "ov.x", level = level.values[2])
     ovx12 <- ovx2[ovx2 %in% ovx1]
     lv.names <- c(lv.names, ovx12)
 
