@@ -1,8 +1,12 @@
-computeSigmaHat <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
+lav_model_sigma <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
                             delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
+  # check.sigma.pd -- new in 0.6-21
+  check.sigma.pd <- get0("opt.check.sigma.pd", lavaan_cache_env,
+                         ifnotfound = "chol")
+
   nmat <- lavmodel@nmat
   nblocks <- lavmodel@nblocks
   representation <- lavmodel@representation
@@ -16,7 +20,7 @@ computeSigmaHat <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      Sigma.hat[[g]] <- computeSigmaHat.LISREL(
+      Sigma.hat[[g]] <- lav_lisrel_sigma(
         MLIST = MLIST,
         delta = delta
       )
@@ -30,32 +34,34 @@ computeSigmaHat <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
 
     if (extra) {
       # check if matrix is positive definite
-      ev <- eigen(Sigma.hat[[g]], symmetric = TRUE, only.values = TRUE)$values
-      if (any(ev < sqrt(.Machine$double.eps)) || sum(ev) == 0) {
+      if (check.sigma.pd == "chol") {
+        # fast path: try Cholesky directly
+        cS <- tryCatch(chol(Sigma.hat[[g]]), error = function(e) NULL)
+        is_pd <- !is.null(cS)
+      } else {
+        # slow path: eigenvalue-based PD check
+        ev <- eigen(Sigma.hat[[g]], symmetric = TRUE, only.values = TRUE)$values
+        is_pd <- !(any(ev < sqrt(.Machine$double.eps)) || sum(ev) == 0)
+      }
+      if (!is_pd) {
         Sigma.hat.inv <- MASS::ginv(Sigma.hat[[g]])
         Sigma.hat.log.det <- log(.Machine$double.eps)
         attr(Sigma.hat[[g]], "po") <- FALSE
         attr(Sigma.hat[[g]], "inv") <- Sigma.hat.inv
         attr(Sigma.hat[[g]], "log.det") <- Sigma.hat.log.det
       } else {
-        ## since we already do an 'eigen' decomposition, we should
-        ## 'reuse' that information, instead of doing a new cholesky?
-        # EV <- eigen(Sigma.hat[[g]], symmetric = TRUE)
-        # Sigma.hat.inv <- tcrossprod(EV$vectors / rep(EV$values,
-        #        each = length(EV$values)), EV$vectors)
-        # Sigma.hat.log.det <- sum(log(EV$values))
-
-        ## --> No, chol() is much (x2) times faster
-        Sigma.hat.inv <- inv.chol(Sigma.hat[[g]], logdet = TRUE)
-        Sigma.hat.log.det <- attr(Sigma.hat.inv, "logdet")
-
+        if (check.sigma.pd != "chol") {
+          cS <- chol(Sigma.hat[[g]])
+        }
+        Sigma.hat.inv <- chol2inv(cS)
+        d <- diag(cS)
+        Sigma.hat.log.det <- 2 * sum(log(d))
         attr(Sigma.hat[[g]], "po") <- TRUE
         attr(Sigma.hat[[g]], "inv") <- Sigma.hat.inv
         attr(Sigma.hat[[g]], "log.det") <- Sigma.hat.log.det
       }
     }
   } # nblocks
-
   Sigma.hat
 }
 
@@ -68,13 +74,17 @@ computeSigmaHat <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
 ##     S12 = PI %*% cov.x
 ##     S21 = cov.x %*% t(PI)
 ##     S22 = cov.x
-computeSigmaHatJoint <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
-                                 delta = TRUE) {
+lav_model_cond2joint_sigma <- function(lavmodel = NULL, GLIST = NULL,
+                                       extra = FALSE, delta = TRUE) {
   stopifnot(lavmodel@conditional.x)
 
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
+  # check.sigma.pd -- new in 0.6-21
+  check.sigma.pd <- get0("opt.check.sigma.pd", lavaan_cache_env,
+                         ifnotfound = "chol")
+
   nmat <- lavmodel@nmat
   nblocks <- lavmodel@nblocks
   representation <- lavmodel@representation
@@ -88,9 +98,9 @@ computeSigmaHatJoint <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      res.Sigma <- computeSigmaHat.LISREL(MLIST = MLIST, delta = delta)
-      # res.int <- computeMuHat.LISREL(MLIST = MLIST)
-      res.slopes <- computePI.LISREL(MLIST = MLIST)
+      res.Sigma <- lav_lisrel_sigma(MLIST = MLIST, delta = delta)
+      # res.int <- lav_lisrel_mu(MLIST = MLIST)
+      res.slopes <- lav_lisrel_pi(MLIST = MLIST)
       S.xx <- MLIST$cov.x
 
       S.yy <- res.Sigma + res.slopes %*% S.xx %*% t(res.slopes)
@@ -106,19 +116,28 @@ computeSigmaHatJoint <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
 
     if (extra) {
       # check if matrix is positive definite
-      ev <- eigen(Sigma.hat[[g]], symmetric = TRUE, only.values = TRUE)$values
-      if (any(ev < .Machine$double.eps) || sum(ev) == 0) {
+      if (check.sigma.pd == "chol") {
+        # fast path: try Cholesky directly
+        cS <- tryCatch(chol(Sigma.hat[[g]]), error = function(e) NULL)
+        is_pd <- !is.null(cS)
+      } else {
+        # slow path: eigenvalue-based PD check
+        ev <- eigen(Sigma.hat[[g]], symmetric = TRUE, only.values = TRUE)$values
+        is_pd <- !(any(ev < sqrt(.Machine$double.eps)) || sum(ev) == 0)
+      }
+      if (!is_pd) {
         Sigma.hat.inv <- MASS::ginv(Sigma.hat[[g]])
         Sigma.hat.log.det <- log(.Machine$double.eps)
         attr(Sigma.hat[[g]], "po") <- FALSE
         attr(Sigma.hat[[g]], "inv") <- Sigma.hat.inv
         attr(Sigma.hat[[g]], "log.det") <- Sigma.hat.log.det
       } else {
-        ## FIXME
-        ## since we already do an 'eigen' decomposition, we should
-        ## 'reuse' that information, instead of doing a new cholesky
-        Sigma.hat.inv <- inv.chol(Sigma.hat[[g]], logdet = TRUE)
-        Sigma.hat.log.det <- attr(Sigma.hat.inv, "logdet")
+        if (check.sigma.pd != "chol") {
+          cS <- chol(Sigma.hat[[g]])
+        }
+        Sigma.hat.inv <- chol2inv(cS)
+        d <- diag(cS)
+        Sigma.hat.log.det <- 2 * sum(log(d))
         attr(Sigma.hat[[g]], "po") <- TRUE
         attr(Sigma.hat[[g]], "inv") <- Sigma.hat.inv
         attr(Sigma.hat[[g]], "log.det") <- Sigma.hat.log.det
@@ -129,7 +148,7 @@ computeSigmaHatJoint <- function(lavmodel = NULL, GLIST = NULL, extra = FALSE,
   Sigma.hat
 }
 
-computeMuHat <- function(lavmodel = NULL, GLIST = NULL) {
+lav_model_mu <- function(lavmodel = NULL, GLIST = NULL) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -149,7 +168,7 @@ computeMuHat <- function(lavmodel = NULL, GLIST = NULL) {
     if (!meanstructure) {
       Mu.hat[[g]] <- numeric(lavmodel@nvar[g])
     } else if (representation == "LISREL") {
-      Mu.hat[[g]] <- computeMuHat.LISREL(MLIST = MLIST)
+      Mu.hat[[g]] <- lav_lisrel_mu(MLIST = MLIST)
     } else if (representation == "RAM") {
       Mu.hat[[g]] <- lav_ram_muhat(MLIST = MLIST)
     } else {
@@ -180,10 +199,14 @@ computeMuHat <- function(lavmodel = NULL, GLIST = NULL) {
 ## Mu (Joint ) = [ Mu.y, Mu.x ] where
 ##     Mu.y = res.int + PI %*% M.x
 ##     Mu.x = M.x
-computeMuHatJoint <- function(lavmodel = NULL, GLIST = NULL) {
+lav_model_cond2joint_mu <- function(lavmodel = NULL, GLIST = NULL) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
+  # check.sigma.pd -- new in 0.6-21
+  check.sigma.pd <- get0("opt.check.sigma.pd", lavaan_cache_env,
+                         ifnotfound = "chol")
+
   nmat <- lavmodel@nmat
   nblocks <- lavmodel@nblocks
   representation <- lavmodel@representation
@@ -200,8 +223,8 @@ computeMuHatJoint <- function(lavmodel = NULL, GLIST = NULL) {
       Mu.hat[[g]] <- numeric(lavmodel@nvar[g])
     } else if (representation == "LISREL") {
       MLIST <- GLIST[mm.in.group]
-      res.int <- computeMuHat.LISREL(MLIST = MLIST)
-      res.slopes <- computePI.LISREL(MLIST = MLIST)
+      res.int <- lav_lisrel_mu(MLIST = MLIST)
+      res.slopes <- lav_lisrel_pi(MLIST = MLIST)
       M.x <- MLIST$mean.x
 
       Mu.y <- res.int + res.slopes %*% M.x
@@ -218,7 +241,7 @@ computeMuHatJoint <- function(lavmodel = NULL, GLIST = NULL) {
 
 # TH.star = DELTA.star * (th.star - pi0.star)
 # see Muthen 1984 eq 11
-computeTH <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
+lav_model_th <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -241,7 +264,7 @@ computeTH <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
     mm.in.group <- 1:nmat[g] + cumsum(c(0, nmat))[g]
 
     if (representation == "LISREL") {
-      TH[[g]] <- computeTH.LISREL(
+      TH[[g]] <- lav_lisrel_th(
         MLIST = GLIST[mm.in.group],
         th.idx = th.idx[[g]], delta = delta
       )
@@ -256,7 +279,7 @@ computeTH <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
 
 # PI = slope structure
 # see Muthen 1984 eq 12
-computePI <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
+lav_model_pi <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -277,7 +300,7 @@ computePI <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
     if (!conditional.x) {
       PI.g <- numeric(lavmodel@nvar[g])
     } else if (representation == "LISREL") {
-      PI.g <- computePI.LISREL(MLIST = MLIST, delta = delta)
+      PI.g <- lav_lisrel_pi(MLIST = MLIST, delta = delta)
     } else {
       lav_msg_stop(gettext(
         "only representation LISREL has been implemented for now"))
@@ -291,7 +314,7 @@ computePI <- function(lavmodel = NULL, GLIST = NULL, delta = TRUE) {
 
 
 # GW = group weight
-computeGW <- function(lavmodel = NULL, GLIST = NULL) {
+lav_model_gw <- function(lavmodel = NULL, GLIST = NULL) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -334,7 +357,7 @@ computeGW <- function(lavmodel = NULL, GLIST = NULL) {
 # *unconditional* variance/covariance matrix of Y
 #  - same as Sigma.hat if all Y are continuous)
 #  - if also Gamma, cov.x is used (only if categorical)
-computeVY <- function(lavmodel = NULL, GLIST = NULL, diagonal.only = FALSE) {
+lav_model_vy <- function(lavmodel = NULL, GLIST = NULL, diagonal.only = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -352,7 +375,7 @@ computeVY <- function(lavmodel = NULL, GLIST = NULL, diagonal.only = FALSE) {
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      VY.g <- computeVY.LISREL(MLIST = MLIST)
+      VY.g <- lav_lisrel_vy(MLIST = MLIST)
     } else if (representation == "RAM") {
       # does not work for categorical setting yet
       stopifnot(!lavmodel@categorical)
@@ -375,8 +398,8 @@ computeVY <- function(lavmodel = NULL, GLIST = NULL, diagonal.only = FALSE) {
 }
 
 # V(ETA): latent variances variances/covariances
-computeVETA <- function(lavmodel = NULL, GLIST = NULL,
-                        remove.dummy.lv = FALSE) {
+lav_model_veta <- function(lavmodel = NULL, GLIST = NULL,
+                           remove.dummy.lv = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -394,7 +417,7 @@ computeVETA <- function(lavmodel = NULL, GLIST = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      VETA.g <- computeVETA.LISREL(MLIST = MLIST)
+      VETA.g <- lav_lisrel_veta(MLIST = MLIST)
 
       if (remove.dummy.lv) {
         # remove all dummy latent variables
@@ -421,7 +444,7 @@ computeVETA <- function(lavmodel = NULL, GLIST = NULL,
 
 # V(ETA|x_i): latent variances variances/covariances, conditional on x_
 # - this is always (I-B)^-1 PSI (I-B)^-T, after REMOVING lv dummies
-computeVETAx <- function(lavmodel = NULL, GLIST = NULL) {
+lav_model_vetax <- function(lavmodel = NULL, GLIST = NULL) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -443,7 +466,7 @@ computeVETAx <- function(lavmodel = NULL, GLIST = NULL) {
         lavmodel@ov.y.dummy.lv.idx[[g]],
         lavmodel@ov.x.dummy.lv.idx[[g]]
       )
-      ETA.g <- computeVETAx.LISREL(
+      ETA.g <- lav_lisrel_vetax(
         MLIST = MLIST,
         lv.dummy.idx = lv.idx
       )
@@ -459,8 +482,8 @@ computeVETAx <- function(lavmodel = NULL, GLIST = NULL) {
 }
 
 # COV: observed+latent variances variances/covariances
-computeCOV <- function(lavmodel = NULL, GLIST = NULL,
-                       remove.dummy.lv = FALSE, delta = TRUE) {
+lav_model_cov_both <- function(lavmodel = NULL, GLIST = NULL,
+                               remove.dummy.lv = FALSE, delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -478,7 +501,7 @@ computeCOV <- function(lavmodel = NULL, GLIST = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      COV.g <- computeCOV.LISREL(MLIST = MLIST, delta = delta)
+      COV.g <- lav_lisrel_cov_both(MLIST = MLIST, delta = delta)
 
       if (remove.dummy.lv) {
         # remove all dummy latent variables
@@ -507,8 +530,8 @@ computeCOV <- function(lavmodel = NULL, GLIST = NULL,
 
 
 # E(ETA): expectation (means) of latent variables (return vector)
-computeEETA <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
-                        remove.dummy.lv = FALSE) {
+lav_model_eeta <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
+                           remove.dummy.lv = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -526,7 +549,7 @@ computeEETA <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      EETA.g <- computeEETA.LISREL(MLIST,
+      EETA.g <- lav_lisrel_eeta(MLIST,
         mean.x = lavsamplestats@mean.x[[g]],
         sample.mean = lavsamplestats@mean[[g]],
         ov.y.dummy.lv.idx = lavmodel@ov.y.dummy.lv.idx[[g]],
@@ -557,8 +580,9 @@ computeEETA <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
 
 # E(ETA|x_i): conditional expectation (means) of latent variables
 # for a given value of x_i (instead of E(x_i))
-computeEETAx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
-                         eXo = NULL, nobs = NULL, remove.dummy.lv = FALSE) {
+lav_model_eetax <- function(lavmodel = NULL, GLIST = NULL,
+                            lavsamplestats = NULL, eXo = NULL,
+                            nobs = NULL, remove.dummy.lv = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -582,7 +606,7 @@ computeEETAx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
     }
 
     if (representation == "LISREL") {
-      EETAx.g <- computeEETAx.LISREL(MLIST,
+      EETAx.g <- lav_lisrel_eetax(MLIST,
         eXo = EXO, N = nobs[[g]],
         sample.mean = lavsamplestats@mean[[g]],
         ov.y.dummy.lv.idx = lavmodel@ov.y.dummy.lv.idx[[g]],
@@ -613,9 +637,9 @@ computeEETAx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
 }
 
 # return 'regular' LAMBDA
-computeLAMBDA <- function(lavmodel = NULL, GLIST = NULL,
-                          handle.dummy.lv = TRUE,
-                          remove.dummy.lv = FALSE) {
+lav_model_lambda <- function(lavmodel = NULL, GLIST = NULL,
+                             handle.dummy.lv = TRUE,
+                             remove.dummy.lv = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -644,7 +668,7 @@ computeLAMBDA <- function(lavmodel = NULL, GLIST = NULL,
         ov.y.dummy.lv.idx <- NULL
         ov.x.dummy.lv.idx <- NULL
       }
-      LAMBDA.g <- computeLAMBDA.LISREL(
+      LAMBDA.g <- lav_lisrel_lambda(
         MLIST = MLIST,
         ov.y.dummy.ov.idx = ov.y.dummy.ov.idx,
         ov.x.dummy.ov.idx = ov.x.dummy.ov.idx,
@@ -664,7 +688,7 @@ computeLAMBDA <- function(lavmodel = NULL, GLIST = NULL,
 }
 
 # THETA: observed (residual) variances
-computeTHETA <- function(lavmodel = NULL, GLIST = NULL, fix = TRUE) {
+lav_model_theta <- function(lavmodel = NULL, GLIST = NULL, fix = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -683,7 +707,7 @@ computeTHETA <- function(lavmodel = NULL, GLIST = NULL, fix = TRUE) {
 
     if (representation == "LISREL") {
       if (fix) {
-        THETA.g <- computeTHETA.LISREL(
+        THETA.g <- lav_lisrel_theta(
           MLIST = MLIST,
           ov.y.dummy.ov.idx = lavmodel@ov.y.dummy.ov.idx[[g]],
           ov.x.dummy.ov.idx = lavmodel@ov.x.dummy.ov.idx[[g]],
@@ -691,7 +715,7 @@ computeTHETA <- function(lavmodel = NULL, GLIST = NULL, fix = TRUE) {
           ov.x.dummy.lv.idx = lavmodel@ov.x.dummy.lv.idx[[g]]
         )
       } else {
-        THETA.g <- computeTHETA.LISREL(MLIST = MLIST)
+        THETA.g <- lav_lisrel_theta(MLIST = MLIST)
       }
     } else if (representation == "RAM") {
       ov.idx <- as.integer(MLIST$ov.idx[1, ])
@@ -708,8 +732,8 @@ computeTHETA <- function(lavmodel = NULL, GLIST = NULL, fix = TRUE) {
 }
 
 # NU: observed intercepts
-computeNU <- function(lavmodel = NULL, GLIST = NULL,
-                      lavsamplestats = NULL) {
+lav_model_nu <- function(lavmodel = NULL, GLIST = NULL,
+                         lavsamplestats = NULL) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -727,7 +751,7 @@ computeNU <- function(lavmodel = NULL, GLIST = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      NU.g <- computeNU.LISREL(
+      NU.g <- lav_lisrel_nu(
         MLIST = MLIST,
         sample.mean = lavsamplestats@mean[[g]],
         ov.y.dummy.ov.idx = lavmodel@ov.y.dummy.ov.idx[[g]],
@@ -748,8 +772,8 @@ computeNU <- function(lavmodel = NULL, GLIST = NULL,
 
 # E(Y): expectation (mean) of observed variables
 # returns vector 1 x nvar
-computeEY <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
-                      delta = TRUE) {
+lav_model_ey <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
+                         delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -767,7 +791,7 @@ computeEY <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      EY.g <- computeEY.LISREL(
+      EY.g <- lav_lisrel_ey(
         MLIST = MLIST,
         mean.x = lavsamplestats@mean.x[[g]],
         sample.mean = lavsamplestats@mean[[g]],
@@ -790,8 +814,8 @@ computeEY <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
 
 # E(Y|x_i): conditional expectation (mean) of observed variables
 # returns matrix N x nvar
-computeEYx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
-                       eXo = NULL, delta = TRUE) {
+lav_model_eyx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
+                          eXo = NULL, delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -809,7 +833,7 @@ computeEYx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
     MLIST <- GLIST[mm.in.group]
 
     if (representation == "LISREL") {
-      EYx.g <- computeEYx.LISREL(
+      EYx.g <- lav_lisrel_eyx(
         MLIST = MLIST,
 		eXo = eXo[[g]],
         sample.mean = lavsamplestats@mean[[g]],
@@ -833,9 +857,9 @@ computeEYx <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
 
 # E(Y | ETA, x_i): conditional expectation (means) of observed variables
 # for a given value of x_i AND eta_i
-computeYHAT <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
-                        eXo = NULL, nobs = NULL, ETA = NULL, duplicate = FALSE,
-                        delta = TRUE) {
+lav_model_yhat <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
+                           eXo = NULL, nobs = NULL, ETA = NULL,
+                           duplicate = FALSE, delta = TRUE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
@@ -860,7 +884,7 @@ computeYHAT <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
 
     if (lavmodel@representation == "LISREL") {
       if (lavmodel@conditional.x) {
-        YHAT[[g]] <- computeEYetax.LISREL(
+        YHAT[[g]] <- lav_lisrel_eyetax(
           MLIST = MLIST,
           eXo = eXo[[g]], ETA = ETA[[g]], N = Nobs,
           sample.mean = lavsamplestats@mean[[g]],
@@ -872,7 +896,7 @@ computeYHAT <- function(lavmodel = NULL, GLIST = NULL, lavsamplestats = NULL,
         )
       } else {
         # unconditional case
-        YHAT[[g]] <- computeEYetax3.LISREL(
+        YHAT[[g]] <- lav_lisrel_eyetax3(
           MLIST = MLIST,
           ETA = ETA[[g]],
           sample.mean = lavsamplestats@mean[[g]],
