@@ -22,11 +22,7 @@ lav_model_gradient <- function(lavmodel = NULL,
   num.idx <- lavmodel@num.idx
   th.idx <- lavmodel@th.idx
   nx.free <- lavmodel@nx.free
-  if (.hasSlot(lavmodel, "estimator.args")) {
-    estimator.args <- lavmodel@estimator.args
-  } else {
-    estimator.args <- list()
-  }
+  estimator.args <- lavmodel@estimator.args
 
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
@@ -63,11 +59,11 @@ lav_model_gradient <- function(lavmodel = NULL,
   if (estimator %in% c("ML", "PML", "FML", "REML", "NTRLS", "catML")) {
     # compute moments for all groups
     # if(conditional.x) {
-    #    Sigma.hat <- computeSigmaHatJoint(lavmodel = lavmodel,
+    #    Sigma.hat <- lav_model_cond2joint_sigma(lavmodel = lavmodel,
     #                     GLIST = GLIST,
     #                     extra = (estimator %in% c("ML", "REML","NTRLS")))
     # } else {
-    Sigma.hat <- computeSigmaHat(
+    Sigma.hat <- lav_model_sigma(
       lavmodel = lavmodel, GLIST = GLIST,
       extra = (estimator %in% c(
         "ML", "REML",
@@ -78,35 +74,35 @@ lav_model_gradient <- function(lavmodel = NULL,
 
     if (meanstructure) {
       # if(conditional.x) {
-      #    Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+      #    Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
       # } else {
-      Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+      Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
       # }
     }
 
     if (categorical) {
-      TH <- computeTH(lavmodel = lavmodel, GLIST = GLIST)
+      TH <- lav_model_th(lavmodel = lavmodel, GLIST = GLIST)
     }
 
     if (conditional.x) {
-      PI <- computePI(lavmodel = lavmodel, GLIST = GLIST)
+      PI <- lav_model_pi(lavmodel = lavmodel, GLIST = GLIST)
     } else if (estimator == "PML") {
       PI <- vector("list", length = lavmodel@nblocks)
     }
 
     if (group.w.free) {
-      GW <- computeGW(lavmodel = lavmodel, GLIST = GLIST)
+      GW <- lav_model_gw(lavmodel = lavmodel, GLIST = GLIST)
     }
   } else if (estimator == "DLS" && estimator.args$dls.GammaNT == "model") {
-    Sigma.hat <- computeSigmaHat(
+    Sigma.hat <- lav_model_sigma(
       lavmodel = lavmodel, GLIST = GLIST,
       extra = FALSE
     )
-    Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+    Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
   } else if (estimator == "MML") {
-    TH <- computeTH(lavmodel = lavmodel, GLIST = GLIST)
-    THETA <- computeTHETA(lavmodel = lavmodel, GLIST = GLIST)
-    GW <- computeGW(lavmodel = lavmodel, GLIST = GLIST)
+    TH <- lav_model_th(lavmodel = lavmodel, GLIST = GLIST)
+    THETA <- lav_model_theta(lavmodel = lavmodel, GLIST = GLIST)
+    GW <- lav_model_gw(lavmodel = lavmodel, GLIST = GLIST)
   }
 
   # four approaches (FIXME!!!! merge this!)
@@ -117,21 +113,16 @@ lav_model_gradient <- function(lavmodel = NULL,
   # - (ML)/NTRLS: using Delta, no support for fixed.x, conditional.x
   # - PML/FML/MML: custom
 
-  composites.flag <- FALSE
-  if (.hasSlot(lavmodel, "composites") && lavmodel@composites) {
-    composites.flag <- TRUE
-  }
+  # composites?
+  composites.flag <- lavmodel@composites
 
   # 1. ML approach
   if ((estimator == "ML" || estimator == "REML" || estimator == "catML") &&
     lavdata@nlevels == 1L && !composites.flag &&
     !lavmodel@conditional.x) {
-	correlation <- FALSE
-	if (.hasSlot(lavmodel, "correlation") && lavmodel@correlation) {
-	  correlation <- TRUE
-	}
+	correlation <- lavmodel@correlation
     if (meanstructure) {
-      Omega <- computeOmega(
+      Omega <- lav_model_omega(
         Sigma.hat = Sigma.hat, Mu.hat = Mu.hat,
         lavsamplestats = lavsamplestats,
         estimator = estimator,
@@ -141,7 +132,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       )
       Omega.mu <- attr(Omega, "mu")
     } else {
-      Omega <- computeOmega(
+      Omega <- lav_model_omega(
         Sigma.hat = Sigma.hat, Mu.hat = NULL,
         lavsamplestats = lavsamplestats,
         estimator = estimator,
@@ -161,7 +152,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       mm.names <- names(GLIST[mm.in.group])
 
       if (representation == "LISREL") {
-        DX.group <- derivative.F.LISREL(
+        DX.group <- lav_lisrel_df_dmlist(
           GLIST[mm.in.group],
           Omega[[g]],
           Omega.mu[[g]]
@@ -199,8 +190,7 @@ lav_model_gradient <- function(lavmodel = NULL,
     # extract free parameters
 
     if (type == "free") {
-      if (.hasSlot(lavmodel, "ceq.simple.only") &&
-        lavmodel@ceq.simple.only) { # new in 0.6-11
+      if (lavmodel@ceq.simple.only) { # new in 0.6-11
         dx <- numeric(lavmodel@nx.unco)
         for (g in 1:lavmodel@nblocks) {
           mm.in.group <- 1:nmat[g] + cumsum(c(0, nmat))[g]
@@ -239,7 +229,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       }
       # stop("FIXME: WLS gradient with type != free needs fixing!")
     } else {
-      Delta <- computeDelta(
+      Delta <- lav_model_delta(
         lavmodel = lavmodel, GLIST. = GLIST,
         ceq.simple = ceq.simple
       )
@@ -345,7 +335,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       # nothing to do
     } else {
       # make a GLIST
-      dx <- lav_model_x2GLIST(
+      dx <- lav_model_x2glist(
         lavmodel = lavmodel, x = dx,
         type = "custom", setDelta = FALSE,
         m.el.idx = m.el.idx,
@@ -363,7 +353,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       }
       # stop("FIXME: WLS gradient with type != free needs fixing!")
     } else {
-      Delta <- computeDelta(
+      Delta <- lav_model_delta(
         lavmodel = lavmodel, GLIST. = GLIST,
         ceq.simple = ceq.simple
       )
@@ -448,7 +438,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       # nothing to do
     } else {
       # make a GLIST
-      dx <- lav_model_x2GLIST(
+      dx <- lav_model_x2glist(
         lavmodel = lavmodel, x = dx,
         type = "custom", setDelta = FALSE,
         m.el.idx = m.el.idx,
@@ -462,7 +452,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       lav_msg_fixme("type != free in lav_model_gradient for
                     estimator ML for nlevels > 1")
     } else {
-      Delta <- computeDelta(
+      Delta <- lav_model_delta(
         lavmodel = lavmodel, GLIST. = GLIST,
         ceq.simple = ceq.simple
       )
@@ -537,7 +527,7 @@ lav_model_gradient <- function(lavmodel = NULL,
     if (type != "free") {
       lav_msg_fixme("type != free in lav_model_gradient for estimator PML")
     } else {
-      Delta <- computeDelta(
+      Delta <- lav_model_delta(
         lavmodel = lavmodel, GLIST. = GLIST,
         ceq.simple = ceq.simple
       )
@@ -558,7 +548,7 @@ lav_model_gradient <- function(lavmodel = NULL,
             "PL gradient + multilevel not implemented;
             try optim.gradient = \"numerical\""))
         } else if (conditional.x) {
-          d1 <- pml_deriv1(
+          d1 <- lav_pml_dploglik_dimplied(
             Sigma.hat = Sigma.hat[[g]],
             Mu.hat = Mu.hat[[g]],
             TH = TH[[g]],
@@ -572,7 +562,7 @@ lav_model_gradient <- function(lavmodel = NULL,
             missing = lavdata@missing
           )
         } else {
-          d1 <- pml_deriv1(
+          d1 <- lav_pml_dploglik_dimplied(
             Sigma.hat = Sigma.hat[[g]],
             Mu.hat = Mu.hat[[g]],
             TH = TH[[g]],
@@ -593,7 +583,7 @@ lav_model_gradient <- function(lavmodel = NULL,
       } # PML
 
       else if (estimator == "FML") {
-        d1 <- fml_deriv1(
+        d1 <- lav_pml_fml_dploglik_dimplied(
           Sigma.hat = Sigma.hat[[g]],
           TH = TH[[g]],
           th.idx = th.idx[[g]],
@@ -637,13 +627,13 @@ lav_model_gradient <- function(lavmodel = NULL,
   # group.w.free for ML
   if (lavmodel@group.w.free &&
     estimator %in% c("ML", "MML", "FML", "PML", "REML", "catML")) {
-    # est.prop <- unlist( computeGW(lavmodel = lavmodel, GLIST = GLIST) )
+    # est.prop <- unlist( lav_model_gw(lavmodel = lavmodel, GLIST = GLIST) )
     # obs.prop <- unlist(lavsamplestats@group.w)
     # FIXME: G2 based -- ML and friends only!!
     # dx.GW <- - (obs.prop - est.prop)
 
     # poisson version
-    est.freq <- exp(unlist(computeGW(lavmodel = lavmodel, GLIST = GLIST)))
+    est.freq <- exp(unlist(lav_model_gw(lavmodel = lavmodel, GLIST = GLIST)))
     obs.freq <- unlist(lavsamplestats@group.w) * lavsamplestats@ntotal
     dx.GW <- -(obs.freq - est.freq)
     # divide by N (to be consistent with the rest of lavaan)
@@ -667,17 +657,17 @@ lav_model_gradient <- function(lavmodel = NULL,
 }
 
 # for testing purposes only
-computeDeltaNumerical <- function(lavmodel = NULL, GLIST = NULL, g = 1L) {
+lav_model_delta_numerical <- function(lavmodel = NULL, GLIST = NULL, g = 1L) {
 
   # state or final?
   if(is.null(GLIST)) GLIST <- lavmodel@GLIST
 
   compute.moments <- function(x) {
-    GLIST <- lav_model_x2GLIST(lavmodel = lavmodel, x = x, type = "free")
-    Sigma.hat <- computeSigmaHat(lavmodel = lavmodel, GLIST = GLIST)
+    GLIST <- lav_model_x2glist(lavmodel = lavmodel, x = x, type = "free")
+    Sigma.hat <- lav_model_sigma(lavmodel = lavmodel, GLIST = GLIST)
     S.vec <- lav_matrix_vech(Sigma.hat[[g]])
     if(lavmodel@meanstructure) {
-      Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST=GLIST)
+      Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST=GLIST)
       out <- c(Mu.hat[[g]], S.vec)
     } else {
       out <- S.vec
@@ -696,17 +686,13 @@ computeDeltaNumerical <- function(lavmodel = NULL, GLIST = NULL, g = 1L) {
 ### FIXME: should we here also:
 ###        - weight for groups? (no, for now)
 ###        - handle equality constraints? (yes, for now)
-computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
+lav_model_delta <- function(lavmodel = NULL, GLIST. = NULL,
                          m.el.idx. = NULL, x.el.idx. = NULL,
                          ceq.simple = FALSE,
                          force.conditional.x.false = FALSE) {
   representation <- lavmodel@representation
   categorical <- lavmodel@categorical
-  if (.hasSlot(lavmodel, "correlation")) {
-    correlation <- lavmodel@correlation
-  } else {
-    correlation <- FALSE
-  }
+  correlation <- lavmodel@correlation
   conditional.x <- lavmodel@conditional.x
   group.w.free <- lavmodel@group.w.free
   nmat <- lavmodel@nmat
@@ -763,7 +749,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
 
   # number of columns in DELTA + m.el.idx/x.el.idx
   if (type == "free") {
-    if (.hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
+    if (lavmodel@ceq.simple.only) {
       NCOL <- lavmodel@nx.unco
     } else {
       NCOL <- lavmodel@nx.free
@@ -771,8 +757,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
     m.el.idx <- x.el.idx <- vector("list", length = length(GLIST))
     for (mm in 1:length(GLIST)) {
       m.el.idx[[mm]] <- lavmodel@m.free.idx[[mm]]
-      if (.hasSlot(lavmodel, "ceq.simple.only") &&
-        lavmodel@ceq.simple.only) {
+      if (lavmodel@ceq.simple.only) {
         x.el.idx[[mm]] <- lavmodel@x.unco.idx[[mm]]
       } else {
         x.el.idx[[mm]] <- lavmodel@x.free.idx[[mm]]
@@ -825,7 +810,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
 
     # if theta, do some preparation
     if (representation == "LISREL" && parameterization == "theta") {
-      sigma.hat <- computeSigmaHat.LISREL(
+      sigma.hat <- lav_lisrel_sigma(
         MLIST = GLIST[mm.in.group],
         delta = FALSE
       )
@@ -845,10 +830,10 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
       if (representation == "LISREL") {
         # Sigma
         DELTA <- dxSigma <-
-          derivative.sigma.LISREL(
+          lav_lisrel_dsigma_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
             idx = m.el.idx[[mm]],
-            MLIST = GLIST[mm.in.group],
             delta = parameterization == "delta"
           )
         if (categorical && parameterization == "theta") {
@@ -881,16 +866,18 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
         if (!categorical) {
           if (conditional.x) {
             # means/intercepts
-            DELTA.mu <- derivative.mu.LISREL(
+            DELTA.mu <- lav_lisrel_dmu_dx(
+              MLIST = GLIST[mm.in.group],
               m = mname,
-              idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+              idx = m.el.idx[[mm]]
             )
 
             # slopes
             if (lavmodel@nexo[g] > 0L) {
-              DELTA.pi <- derivative.pi.LISREL(
+              DELTA.pi <- lav_lisrel_dpi_dx(
+                 MLIST = GLIST[mm.in.group],
                 m = mname,
-                idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+                idx = m.el.idx[[mm]]
               )
 
               if (lavmodel@multilevel) {
@@ -919,18 +906,19 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
               DELTA <- rbind(DELTA.mu, DELTA)
             }
           } else if (!conditional.x && lavmodel@meanstructure) {
-            DELTA.mu <- derivative.mu.LISREL(
+            DELTA.mu <- lav_lisrel_dmu_dx(
+               MLIST = GLIST[mm.in.group],
               m = mname,
-              idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+              idx = m.el.idx[[mm]]
             )
             DELTA <- rbind(DELTA.mu, DELTA)
           }
         } else if (categorical) {
-          DELTA.th <- derivative.th.LISREL(
+          DELTA.th <- lav_lisrel_dth_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
             idx = m.el.idx[[mm]],
             th.idx = th.idx[[g]],
-            MLIST = GLIST[mm.in.group],
             delta = TRUE
           )
           if (parameterization == "theta") {
@@ -939,10 +927,10 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
               (dxSigma[theta.var.idx, , drop = FALSE] *
                 -0.5 / (dsigma * sqrt(dsigma)))
             dth.dDelta <-
-              derivative.th.LISREL(
+              lav_lisrel_dth_dx(
+                MLIST = GLIST[mm.in.group],
                 m = "delta",
                 idx = 1:nvar[g],
-                MLIST = GLIST[mm.in.group],
                 th.idx = th.idx[[g]]
               )
             # add dth.dDelta %*% dDelta.dx
@@ -953,17 +941,17 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
           }
           if (conditional.x && lavmodel@nexo[g] > 0L) {
             DELTA.pi <-
-              derivative.pi.LISREL(
+              lav_lisrel_dpi_dx(
+                MLIST = GLIST[mm.in.group],
                 m = mname,
-                idx = m.el.idx[[mm]],
-                MLIST = GLIST[mm.in.group]
+                idx = m.el.idx[[mm]]
               )
             if (parameterization == "theta") {
               dpi.dDelta <-
-                derivative.pi.LISREL(
+                lav_lisrel_dpi_dx(
+                  MLIST = GLIST[mm.in.group],
                   m = "delta",
-                  idx = 1:nvar[g],
-                  MLIST = GLIST[mm.in.group]
+                  idx = 1:nvar[g]
                 )
               # add dpi.dDelta %*% dDelta.dx
               no.num.idx <-
@@ -981,10 +969,10 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
           }
         }
         if (group.w.free) {
-          DELTA.gw <- derivative.gw.LISREL(
+          DELTA.gw <- lav_lisrel_dgw_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]],
-            MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
           DELTA <- rbind(DELTA.gw, DELTA)
         }
@@ -1011,8 +999,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
     } # mm
 
     # if type == "free" take care of equality constraints
-    if (type == "free" && ceq.simple &&
-      .hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
+    if (type == "free" && ceq.simple && lavmodel@ceq.simple.only) {
       Delta.group <- Delta.group %*% lavmodel@ceq.simple.K
     }
 
@@ -1020,7 +1007,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
   } # g
 
   # if multilevel, rbind levels within group
-  if (.hasSlot(lavmodel, "multilevel") && lavmodel@multilevel) {
+  if (lavmodel@multilevel) {
     DELTA <- vector("list", length = lavmodel@ngroups)
     for (g in 1:lavmodel@ngroups) {
       DELTA[[g]] <- rbind(
@@ -1034,7 +1021,7 @@ computeDelta <- function(lavmodel = NULL, GLIST. = NULL,
   Delta
 }
 
-computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
+lav_model_ddelta_dx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
                            ceq.simple = FALSE) {
   # state or final?
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
@@ -1047,7 +1034,7 @@ computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
   # number of columns in DELTA + m.el.idx/x.el.idx
   type <- "free"
   # if(type == "free") {
-  if (.hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
+  if (lavmodel@ceq.simple.only) {
     NCOL <- lavmodel@nx.unco
   } else {
     NCOL <- lavmodel@nx.free
@@ -1055,8 +1042,7 @@ computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
   m.el.idx <- x.el.idx <- vector("list", length = length(GLIST))
   for (mm in 1:length(GLIST)) {
     m.el.idx[[mm]] <- lavmodel@m.free.idx[[mm]]
-    if (.hasSlot(lavmodel, "ceq.simple.only") &&
-      lavmodel@ceq.simple.only) {
+    if (lavmodel@ceq.simple.only) {
       x.el.idx[[mm]] <- lavmodel@x.unco.idx[[mm]]
     } else {
       x.el.idx[[mm]] <- lavmodel@x.free.idx[[mm]]
@@ -1090,60 +1076,70 @@ computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
       # get Delta columns for this model matrix
       if (representation == "LISREL") {
         if (target == "lambda") {
-          DELTA <- derivative.lambda.LISREL(
+         DELTA <- lav_lisrel_dlambda_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "th") {
-          DELTA <- derivative.th.LISREL(
-            m = mname, th.idx = th.idx[[g]],
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group],
+          DELTA <- lav_lisrel_dth_dx(
+             MLIST = GLIST[mm.in.group], m = mname, th.idx = th.idx[[g]],
+            idx = m.el.idx[[mm]],
             delta = TRUE
           )
         } else if (target == "mu") {
-          DELTA <- derivative.mu.LISREL(
+          DELTA <- lav_lisrel_dmu_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "nu") {
-          DELTA <- derivative.nu.LISREL(
+          DELTA <- lav_lisrel_dnu_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "tau") {
-          DELTA <- derivative.tau.LISREL(
+          DELTA <- lav_lisrel_dtau_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "theta") {
-          DELTA <- derivative.theta.LISREL(
+          DELTA <- lav_lisrel_dtheta_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "gamma") {
-          DELTA <- derivative.gamma.LISREL(
+          DELTA <- lav_lisrel_dgamma_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "beta") {
-          DELTA <- derivative.beta.LISREL(
+          DELTA <- lav_lisrel_dbeta_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "alpha") {
-          DELTA <- derivative.alpha.LISREL(
+          DELTA <- lav_lisrel_dalpha_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "psi") {
-          DELTA <- derivative.psi.LISREL(
+          DELTA <- lav_lisrel_dpsi_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group]
+            idx = m.el.idx[[mm]]
           )
         } else if (target == "sigma") {
-          DELTA <- derivative.sigma.LISREL(
+          DELTA <- lav_lisrel_dsigma_dx(
+            MLIST = GLIST[mm.in.group],
             m = mname,
-            idx = m.el.idx[[mm]], MLIST = GLIST[mm.in.group],
+            idx = m.el.idx[[mm]],
             delta = TRUE
           )
         } else {
@@ -1158,8 +1154,7 @@ computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
       }
     } # mm
 
-    if (type == "free" && ceq.simple &&
-      .hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
+    if (type == "free" && ceq.simple && lavmodel@ceq.simple.only) {
       Delta.group <- Delta.group %*% lavmodel@ceq.simple.K
     }
 
@@ -1169,7 +1164,7 @@ computeDeltaDx <- function(lavmodel = NULL, GLIST = NULL, target = "lambda",
   Delta
 }
 
-computeOmega <- function(Sigma.hat = NULL, Mu.hat = NULL,
+lav_model_omega <- function(Sigma.hat = NULL, Mu.hat = NULL,
                          lavsamplestats = NULL, estimator = "ML",
                          meanstructure = FALSE, conditional.x = FALSE,
 						 correlation = FALSE) {
@@ -1229,9 +1224,7 @@ computeOmega <- function(Sigma.hat = NULL, Mu.hat = NULL,
           nobs <- M[[p]][["freq"]]
           var.idx <- M[[p]][["var.idx"]]
 
-          Sigma.inv <- inv.chol(Sigma.hat[[g]][var.idx, var.idx],
-            logdet = FALSE
-          )
+          Sigma.inv <- chol2inv(chol(Sigma.hat[[g]][var.idx, var.idx]))
           Mu <- Mu.hat[[g]][var.idx]
           W.tilde <- SX + tcrossprod(MX - Mu)
 
@@ -1276,14 +1269,14 @@ lav_model_gradient_DD <- function(lavmodel, GLIST = NULL, group = 1L) {
   if (is.null(GLIST)) GLIST <- lavmodel@GLIST
 
   #### FIX th + mu!!!!!
-  Delta.lambda <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "lambda")[[group]]
-  Delta.tau <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "tau")[[group]]
-  Delta.nu <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "nu")[[group]]
-  Delta.theta <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "theta")[[group]]
-  Delta.beta <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "beta")[[group]]
-  Delta.psi <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "psi")[[group]]
-  Delta.alpha <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "alpha")[[group]]
-  Delta.gamma <- computeDeltaDx(lavmodel, GLIST = GLIST, target = "gamma")[[group]]
+  Delta.lambda <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "lambda")[[group]]
+  Delta.tau <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "tau")[[group]]
+  Delta.nu <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "nu")[[group]]
+  Delta.theta <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "theta")[[group]]
+  Delta.beta <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "beta")[[group]]
+  Delta.psi <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "psi")[[group]]
+  Delta.alpha <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "alpha")[[group]]
+  Delta.gamma <- lav_model_ddelta_dx(lavmodel, GLIST = GLIST, target = "gamma")[[group]]
 
   ov.y.dummy.ov.idx <- lavmodel@ov.y.dummy.ov.idx[[group]]
   ov.x.dummy.ov.idx <- lavmodel@ov.x.dummy.ov.idx[[group]]
