@@ -103,7 +103,7 @@ lav_model_nvcov_robust_sem <- function(lavmodel = NULL,
                                        attr.E.inv = FALSE,
                                        attr.WLS.V = FALSE) {
   # compute inverse of the expected(!) information matrix
-  if (lavmodel@estimator == "ML" && lavoptions$mimic == "Mplus") {
+  if (lavmodel@estimator == "ML" && lavoptions$information.expected.mplus) {
     # YR - 11 aug 2010 - what Mplus seems to do is (see Muthen apx 4 eq102)
     # - A1 is not based on Sigma.hat and Mu.hat,
     # but on lavsamplestats@cov and lavsamplestats@mean... ('unstructured')
@@ -145,7 +145,7 @@ lav_model_nvcov_robust_sem <- function(lavmodel = NULL,
   # Gamma
   Gamma <- lavsamplestats@NACOV
   if (lavmodel@estimator == "ML" &&
-    lavoptions$mimic == "Mplus" && !lavsamplestats@NACOV.user) {
+    lavoptions$gamma.vcov.mplus && !lavsamplestats@NACOV.user) {
     # 'fix' G11 part of Gamma (NOTE: this is NOT needed for SB test
     # statistic
     for (g in 1:lavsamplestats@ngroups) {
@@ -164,7 +164,7 @@ lav_model_nvcov_robust_sem <- function(lavmodel = NULL,
   tDVGVD <- matrix(0, ncol = ncol(E.inv), nrow = nrow(E.inv))
   for (g in 1:lavsamplestats@ngroups) {
     fg <- lavsamplestats@nobs[[g]] / lavsamplestats@ntotal
-    if (lavoptions$mimic == "Mplus") {
+    if (lavoptions$gamma.vcov.mplus) {
       fg1 <- (lavsamplestats@nobs[[g]] - 1) / lavsamplestats@ntotal
     } else {
       # from 0.6 onwards, we use fg1 == fg, to be more consistent with
@@ -508,7 +508,7 @@ lav_model_vcov <- function(lavmodel = NULL,
         inverted = TRUE,
         use.ginv = use.ginv
       )
-  } else if (se == "robust.sem" || se == "robust.cluster.sem") {
+  } else if (se %in% c("robust.sem", "robust.sem.nt", "robust.cluster.sem")) {
     NVarCov <-
       lav_model_nvcov_robust_sem(
         lavmodel = lavmodel,
@@ -570,7 +570,6 @@ lav_model_vcov <- function(lavmodel = NULL,
         # new in 0.6-9 (to mimic method="lm" in effectLite)
         # special case: univariate regression in each group
         if (lavoptions$mimic == "lm" &&
-          .hasSlot(lavmodel, "modprop") &&
           all(lavmodel@modprop$uvreg)) {
           N <- sum(unlist(lavsamplestats@nobs) -
             (unlist(lavmodel@modprop$nexo) + 1L))
@@ -591,7 +590,7 @@ lav_model_vcov <- function(lavmodel = NULL,
 
     # check if VarCov is pd -- new in 0.6-2
     # mostly important if we have (in)equality constraints (MASS::ginv!)
-    if (.hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
+    if (lavmodel@ceq.simple.only) {
       # do nothing
     } else if (!is.null(lavoptions$check.vcov) && lavoptions$check.vcov) {
       eigvals <- eigen(VarCov,
@@ -681,13 +680,13 @@ lav_model_vcov_se <- function(lavmodel, lavpartable, VCOV = NULL,
   # check for negative values (what to do: NA or 0.0?)
   x.var[x.var < 0] <- as.numeric(NA)
   x.se <- sqrt(x.var)
-  if (.hasSlot(lavmodel, "ceq.simple.only") && lavmodel@ceq.simple.only) {
-    GLIST <- lav_model_x2GLIST(
+  if (lavmodel@ceq.simple.only) {
+    GLIST <- lav_model_x2glist(
       lavmodel = lavmodel, x = x.se,
       type = "unco"
     )
   } else {
-    GLIST <- lav_model_x2GLIST(
+    GLIST <- lav_model_x2glist(
       lavmodel = lavmodel, x = x.se,
       type = "free"
     )
@@ -746,8 +745,7 @@ lav_model_vcov_se <- function(lavmodel, lavpartable, VCOV = NULL,
       if (inherits(JAC, "try-error")) { # eg. pnorm()
         JAC <- lav_func_jacobian_simple(func = lavmodel@def.function, x = x)
       }
-      if (.hasSlot(lavmodel, "ceq.simple.only") &&
-        lavmodel@ceq.simple.only) {
+      if (lavmodel@ceq.simple.only) {
         JAC <- JAC %*% t(lavmodel@ceq.simple.K)
       }
       def.cov <- JAC %*% VCOV %*% t(JAC)
