@@ -15,44 +15,44 @@
 # - 24 March 2019: handle efa sets
 # - 23 May   2020: support for random slopes
 
-lavaanify <- lavParTable <- function(
-                                     model = NULL,
-                                     meanstructure = FALSE,
-                                     int.ov.free = FALSE,
-                                     int.lv.free = FALSE,
-                                     marker.int.zero = FALSE,
-                                     orthogonal = FALSE,
-                                     orthogonal.y = FALSE,
-                                     orthogonal.x = FALSE,
-                                     orthogonal.efa = FALSE,
-                                     std.lv = FALSE,
-                                     correlation = FALSE,
-                                     composites = TRUE,
-                                     effect.coding = "",
-                                     conditional.x = FALSE,
-                                     fixed.x = FALSE,
-                                     parameterization = "delta",
-                                     constraints = NULL,
-                                     ceq.simple = FALSE,
-                                     auto = FALSE,
-                                     model.type = "sem",
-                                     auto.fix.first = FALSE,
-                                     auto.fix.single = FALSE,
-                                     auto.var = FALSE,
-                                     auto.cov.lv.x = FALSE,
-                                     auto.cov.y = FALSE,
-                                     auto.th = FALSE,
-                                     auto.delta = FALSE,
-                                     auto.efa = FALSE,
-                                     varTable = NULL, # nolint
-                                     ngroups = 1L,
-                                     nthresholds = NULL,
-                                     group.equal = NULL,
-                                     group.partial = NULL,
-                                     group.w.free = FALSE,
-                                     debug = FALSE,
-                                     warn = TRUE,
-                                     as.data.frame. = TRUE) { # nolint
+lav_model_partable  <- function(
+                                model = NULL,
+                                meanstructure = FALSE,
+                                int.ov.free = FALSE,
+                                int.lv.free = FALSE,
+                                marker.int.zero = FALSE,
+                                orthogonal = FALSE,
+                                orthogonal.y = FALSE,
+                                orthogonal.x = FALSE,
+                                orthogonal.efa = FALSE,
+                                std.lv = FALSE,
+                                correlation = FALSE,
+                                composites = TRUE,
+                                effect.coding = "",
+                                conditional.x = FALSE,
+                                fixed.x = FALSE,
+                                parameterization = "delta",
+                                constraints = NULL,
+                                ceq.simple = FALSE,
+                                auto = FALSE,
+                                model.type = "sem",
+                                auto.fix.first = FALSE,
+                                auto.fix.single = FALSE,
+                                auto.var = FALSE,
+                                auto.cov.lv.x = FALSE,
+                                auto.cov.y = FALSE,
+                                auto.th = FALSE,
+                                auto.delta = FALSE,
+                                auto.efa = FALSE,
+                                varTable = NULL, # nolint
+                                ngroups = 1L,
+                                nthresholds = NULL,
+                                group.equal = NULL,
+                                group.partial = NULL,
+                                group.w.free = FALSE,
+                                debug = FALSE,
+                                warn = TRUE,
+                                as.data.frame. = TRUE) { # nolint
   if (!missing(debug)) {
     current.debug <- lav_debug()
     if (lav_debug(debug))
@@ -454,7 +454,7 @@ lavaanify <- lavParTable <- function(
 
   # check ordinal variables
   categorical <- FALSE
-  ov.ord <- lavNames(tmp.list, "ov.ord")
+  ov.ord <- lav_object_vnames(tmp.list, "ov.ord")
   if (length(ov.ord) > 0L) {
     categorical <- TRUE
     ord.var.idx <- which(tmp.list$op == "~~" &
@@ -1253,3 +1253,5 @@ lavaanify <- lavParTable <- function(
 
   tmp.list
 }
+lavParTable <- lav_model_partable   # synonym #nolint
+lavaanify <- lav_model_partable     # synonym #nolint
