@@ -2,7 +2,7 @@
 # the unifying theme is that they all rely on the (unknown, to be estimated)
 # or (known, apriori specified) values for the latent variables
 #
-# lv: lavtent variables (aka `factor scores')
+# lv: latent variables (aka `factor scores')
 # ov: predict linear part of y_i
 #
 # - YR 11 June 2013: first version, in order to get factor scores for the
@@ -32,7 +32,7 @@ setMethod(
 )
 
 # efaList version
-predict.efaList <- function(object, ...) {
+lav_efalist_predict <- function(object, ...) {
   # kill object$loadings if present
   object[["loadings"]] <- NULL
 
@@ -55,6 +55,9 @@ lavPredict <- function(object, newdata = NULL, # keep order of predict(), 0.6-7
                        append.data = FALSE, assemble = FALSE, # or TRUE?
                        level = 1L, optim.method = "bfgs", ETA = NULL,
                        drop.list.single.group = TRUE) {
+  # check object
+  object <- lav_object_check_version(object)
+
   # catch efaList objects
   if (inherits(object, "efaList")) {
     # kill object$loadings if present
@@ -72,21 +75,12 @@ lavPredict <- function(object, newdata = NULL, # keep order of predict(), 0.6-7
   lavmodel <- object@Model
   lavdata <- object@Data
   lavsamplestats <- object@SampleStats
-  # backward compatibility
-  if (.hasSlot(object, "h1")) {
-    lavh1 <- object@h1
-  } else {
-    lavh1 <- lav_h1_implied_logl(
-      lavdata = object@Data,
-      lavsamplestats = object@SampleStats,
-      lavoptions = object@Options
-    )
-  }
+  lavh1 <- object@h1
   lavimplied <- object@implied
   lavpartable <- object@ParTable
 
   # warn if the model does not contain any 'regular' latent variables
-  if (length(lavNames(lavpartable, "lv.regular")) == 0L) {
+  if (length(lav_object_vnames(lavpartable, "lv.regular")) == 0L) {
     lav_msg_warn(gettextf("fitted model does not contain regular
     (i.e., measured) latent variables; the matrix of factor scores may
     contain no columns"))
@@ -189,7 +183,7 @@ lav_predict_internal <- function(lavmodel = NULL,
     eXo <- lavdata@eXo
   } else {
     OV <- lavdata@ov
-    newData <- lavData(
+    newData <- lav_lavdata(
       data = newdata,
       group = lavdata@group,
       ov.names = lavdata@ov.names,
@@ -240,7 +234,7 @@ lav_predict_internal <- function(lavmodel = NULL,
       lavdata = lavdata, lavsamplestats = lavsamplestats,
       lavimplied = lavimplied, se = se, acov = acov, level = level,
       data.obs = data.obs, eXo = eXo, method = method,
-      fsm = fsm, rel = rel, optim.method = optim.method
+      fsm = fsm, rel = rel, transform = transform, optim.method = optim.method
     )
 
     # extract fsm here
@@ -265,13 +259,13 @@ lav_predict_internal <- function(lavmodel = NULL,
     out <- lapply(seq_len(lavdata@ngroups), function(g) {
       # determine block
       if (lavdata@nlevels == 1L) {
-        bb <- g
+        b <- g
       } else {
-        bb <- (g - 1) * lavdata@nlevels + level
+        b <- (g - 1) * lavdata@nlevels + level
       }
       lv.idx <- c(
-        lavmodel@ov.y.dummy.lv.idx[[bb]],
-        lavmodel@ov.x.dummy.lv.idx[[bb]]
+        lavmodel@ov.y.dummy.lv.idx[[b]],
+        lavmodel@ov.x.dummy.lv.idx[[b]]
       )
       ret <- out[[g]]
       if (length(lv.idx) > 0L) {
@@ -281,21 +275,22 @@ lav_predict_internal <- function(lavmodel = NULL,
     })
 
     # we need to remove the dummy's before we transform
+    # (update 0.6-20: no longer needed... as transform happens internally)
     if (fsm) {
       FSM <- lapply(seq_len(lavdata@ngroups), function(g) {
         # determine block
         if (lavdata@nlevels == 1L) {
-          bb <- g
+          b <- g
         } else {
-          bb <- (g - 1) * lavdata@nlevels + level
+          b <- (g - 1) * lavdata@nlevels + level
         }
         lv.idx <- c(
-          lavmodel@ov.y.dummy.lv.idx[[bb]],
-          lavmodel@ov.x.dummy.lv.idx[[bb]]
+          lavmodel@ov.y.dummy.lv.idx[[b]],
+          lavmodel@ov.x.dummy.lv.idx[[b]]
         )
-        # ov.idx <- lavmodel@ov.x.dummy.ov.idx[[bb]]
+        # ov.idx <- lavmodel@ov.x.dummy.ov.idx[[b]]
         # or should we use pta$vidx$ov.ind?
-        ov.ind <- lavpta$vidx$ov.ind[[bb]]
+        ov.ind <- lavpta$vidx$ov.ind[[b]]
         ret <- FSM[[g]]
         if (length(lv.idx) > 0L) {
           if (is.matrix(FSM[[g]])) {
@@ -311,68 +306,68 @@ lav_predict_internal <- function(lavmodel = NULL,
       })
     }
 
-    # new in 0.6-16
-    # we assume the dummy lv's have already been removed
-    if (transform) {
-      # VETA <- computeVETA(lavmodel = lavmodel, remove.dummy.lv = TRUE)
-      EETA <- computeEETA(
-        lavmodel = lavmodel,
-        lavsamplestats = lavsamplestats, remove.dummy.lv = TRUE
-      )
-      # compute transformation matrix
-      if (tolower(method) %in% c("ebm", "regression")) {
-        tmat <- lav_predict_tmat_green(lavmodel = lavmodel,
-                                       lavimplied = lavimplied)
-      } else {
-        tmat <- lav_predict_tmat_det(lavmodel = lavmodel,
-                                     lavimplied = lavimplied)
-      }
-
-      # update FSM
-      if (fsm) {
-        FSM <- lapply(seq_len(lavdata@ngroups), function(g) {
-          # determine block
-          if (lavdata@nlevels == 1L) {
-            bb <- g
-          } else {
-            bb <- (g - 1) * lavdata@nlevels + level
-          }
-          ret <- tmat[[bb]] %*% FSM[[g]]
-          ret
-        })
-      }
-
-      out <- lapply(seq_len(lavdata@ngroups), function(g) {
-        # determine block
-        if (lavdata@nlevels == 1L) {
-          bb <- g
-        } else {
-          bb <- (g - 1) * lavdata@nlevels + level
-        }
-
-        FS.centered <- scale(out[[g]], center = TRUE, scale = FALSE)
-        #FS.cov <- crossprod(FS.centered) / nrow(FS.centered)
-        #FS.cov.inv <- try(solve(FS.cov), silent = TRUE)
-        #if (inherits(FS.cov.inv, "try-error")) {
-        #  lav_msg_warn(
-        #    gettext("could not invert (co)variance matrix of factor scores;
-        #            returning original factor scores."))
-        #  return(out[[g]])
-        #}
-        #fs.inv.sqrt <- lav_matrix_symmetric_sqrt(FS.cov.inv)
-        #veta.sqrt <- lav_matrix_symmetric_sqrt(VETA[[g]])
-        #tmp <- FS.centered %*% fs.inv.sqrt %*% veta.sqrt
-        tmp <- FS.centered %*% t(tmat[[bb]])
-        ret <- t(t(tmp) + drop(EETA[[g]]))
-
-        ret
-      })
-    }
+#   # new in 0.6-16
+#   # we assume the dummy lv's have already been removed
+#     if (transform) {
+#       # VETA <- lav_model_veta(lavmodel = lavmodel, remove.dummy.lv = TRUE)
+#       EETA <- lav_model_eeta(
+#         lavmodel = lavmodel,
+#         lavsamplestats = lavsamplestats, remove.dummy.lv = TRUE
+#       )
+#       # compute transformation matrix
+#       if (tolower(method) %in% c("ebm", "regression")) {
+#         tmat <- lav_predict_tmat_green(lavmodel = lavmodel,
+#                                        lavimplied = lavimplied)
+#       } else {
+#         tmat <- lav_predict_tmat_det(lavmodel = lavmodel,
+#                                      lavimplied = lavimplied)
+#       }
+#
+#       # update FSM
+#       if (fsm) {
+#         FSM <- lapply(seq_len(lavdata@ngroups), function(g) {
+#           # determine block
+#           if (lavdata@nlevels == 1L) {
+#             b <- g
+#           } else {
+#             b <- (g - 1) * lavdata@nlevels + level
+#           }
+#           ret <- tmat[[b]] %*% FSM[[g]]
+#           ret
+#         })
+#       }
+#
+#       out <- lapply(seq_len(lavdata@ngroups), function(g) {
+#         # determine block
+#         if (lavdata@nlevels == 1L) {
+#           b <- g
+#         } else {
+#           b <- (g - 1) * lavdata@nlevels + level
+#         }
+#
+#         FS.centered <- scale(out[[g]], center = TRUE, scale = FALSE)
+#         #FS.cov <- crossprod(FS.centered) / nrow(FS.centered)
+#         #FS.cov.inv <- try(solve(FS.cov), silent = TRUE)
+#         #if (inherits(FS.cov.inv, "try-error")) {
+#         #  lav_msg_warn(
+#         #    gettext("could not invert (co)variance matrix of factor scores;
+#         #            returning original factor scores."))
+#         #  return(out[[g]])
+#         #}
+#         #fs.inv.sqrt <- lav_matrix_symmetric_sqrt(FS.cov.inv)
+#         #veta.sqrt <- lav_matrix_symmetric_sqrt(VETA[[g]])
+#         #tmp <- FS.centered %*% fs.inv.sqrt %*% veta.sqrt
+#         tmp <- FS.centered %*% t(tmat[[b]])
+#         ret <- t(t(tmp) + drop(EETA[[g]]))
+#
+#         ret
+#       })
+#     }
 
     # new in 0.6-17
     if (mdist) {
-      VETA <- computeVETA(lavmodel = lavmodel, remove.dummy.lv = TRUE)
-      EETA <- computeEETA(
+      VETA <- lav_model_veta(lavmodel = lavmodel, remove.dummy.lv = TRUE)
+      EETA <- lav_model_eeta(
         lavmodel = lavmodel,
         lavsamplestats = lavsamplestats, remove.dummy.lv = TRUE
       )
@@ -405,13 +400,13 @@ lav_predict_internal <- function(lavmodel = NULL,
       SE <- lapply(seq_len(lavdata@ngroups), function(g) {
         # determine block
         if (lavdata@nlevels == 1L) {
-          bb <- g
+          b <- g
         } else {
-          bb <- (g - 1) * lavdata@nlevels + level
+          b <- (g - 1) * lavdata@nlevels + level
         }
         lv.idx <- c(
-          lavmodel@ov.y.dummy.lv.idx[[bb]],
-          lavmodel@ov.x.dummy.lv.idx[[bb]]
+          lavmodel@ov.y.dummy.lv.idx[[b]],
+          lavmodel@ov.x.dummy.lv.idx[[b]]
         )
         ret <- SE[[g]]
         if (length(lv.idx) > 0L) {
@@ -423,13 +418,13 @@ lav_predict_internal <- function(lavmodel = NULL,
         ACOV <- lapply(seq_len(lavdata@ngroups), function(g) {
           # determine block
           if (lavdata@nlevels == 1L) {
-            bb <- g
+            b <- g
           } else {
-            bb <- (g - 1) * lavdata@nlevels + level
+            b <- (g - 1) * lavdata@nlevels + level
           }
           lv.idx <- c(
-            lavmodel@ov.y.dummy.lv.idx[[bb]],
-            lavmodel@ov.x.dummy.lv.idx[[bb]]
+            lavmodel@ov.y.dummy.lv.idx[[b]],
+            lavmodel@ov.x.dummy.lv.idx[[b]]
           )
           ret <- ACOV[[g]]
           if (length(lv.idx) > 0L) {
@@ -557,7 +552,7 @@ lav_predict_internal <- function(lavmodel = NULL,
 
     # mdist
     if (mdist) {
-      LAMBDA <- computeLAMBDA(
+      LAMBDA <- lav_model_lambda(
         lavmodel = lavmodel,
         remove.dummy.lv = FALSE
       )
@@ -706,6 +701,7 @@ lav_predict_eta <- function(lavobject = NULL, # for convenience
                             method = "EBM",
                             fsm = FALSE,
 							rel = FALSE,
+                            transform = FALSE,
                             se = "none", acov = "none",
                             level = 1L,
                             optim.method = "bfgs") {
@@ -734,7 +730,8 @@ lav_predict_eta <- function(lavobject = NULL, # for convenience
         lavmodel = lavmodel, lavdata = lavdata,
         lavimplied = lavimplied, se = se, acov = acov,
         level = level, lavsamplestats = lavsamplestats,
-        data.obs = data.obs, eXo = eXo, fsm = fsm, rel = rel
+        data.obs = data.obs, eXo = eXo, fsm = fsm, rel = rel,
+        transform = transform
       )
     } else if (method == "ml") {
       out <- lav_predict_eta_bartlett(
@@ -742,7 +739,8 @@ lav_predict_eta <- function(lavobject = NULL, # for convenience
         lavmodel = lavmodel, lavdata = lavdata,
         lavimplied = lavimplied, se = se, acov = acov,
         level = level, lavsamplestats = lavsamplestats,
-        data.obs = data.obs, eXo = eXo, fsm = fsm, rel = rel
+        data.obs = data.obs, eXo = eXo, fsm = fsm, rel = rel,
+        transform = transform
       )
     } else {
       lav_msg_stop(gettextf("unkown method: %s.", method))
@@ -784,7 +782,8 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
                                    # optional new data
                                    data.obs = NULL, eXo = NULL,
                                    se = "none", acov = "none", level = 1L,
-                                   fsm = FALSE, rel = FALSE) {
+                                   fsm = FALSE, rel = FALSE,
+                                   transform = FALSE) {
   # full object?
   if (inherits(lavobject, "lavaan")) {
     lavmodel <- lavobject@Model
@@ -818,12 +817,12 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
     }
   }
 
-  LAMBDA <- computeLAMBDA(lavmodel = lavmodel, remove.dummy.lv = FALSE)
+  LAMBDA <- lav_model_lambda(lavmodel = lavmodel, remove.dummy.lv = FALSE)
   Sigma.hat <- lavimplied$cov
   Sigma.inv <- lapply(Sigma.hat, MASS::ginv)
-  VETA <- computeVETA(lavmodel = lavmodel)
-  EETA <- computeEETA(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
-  EY <- computeEY(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
+  VETA <- lav_model_veta(lavmodel = lavmodel)
+  EETA <- lav_model_eeta(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
+  EY <- lav_model_ey(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
 
   FS <- vector("list", length = lavdata@ngroups)
   if (fsm) {
@@ -832,6 +831,10 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
   if (rel) {
     REL <- vector("list", length = lavdata@ngroups)
   }
+  if (transform) {
+    TMAT <- lav_predict_tmat_green(lavmodel = lavmodel,
+                                   lavimplied = lavimplied)
+  }
 
   if (acov != "none") {
     se <- acov # ACOV implies SE
@@ -845,6 +848,19 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
   }
 
   for (g in 1:lavdata@ngroups) {
+    # determine block
+    if (lavdata@nlevels == 1L) {
+      b <- g
+    } else {
+      b <- (g - 1) * lavdata@nlevels + level
+    }
+
+    VETA.g <- VETA[[b]]
+    EETA.g <- EETA[[b]]
+    LAMBDA.g <- LAMBDA[[b]]
+    EY.g <- EY[[b]]
+    Sigma.inv.g <- Sigma.inv[[b]]
+
     if (lavdata@nlevels > 1L) {
       Lp <- lavdata@Lp[[g]]
       YLp <- lavsamplestats@YLp[[g]]
@@ -891,23 +907,11 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
       } else {
         lav_msg_stop(gettext("only 2 levels are supported"))
       }
-
-      gg <- (g - 1) * lavdata@nlevels + level
-      VETA.g <- VETA[[gg]]
-      EETA.g <- EETA[[gg]]
-      LAMBDA.g <- LAMBDA[[gg]]
-      EY.g <- EY[[gg]]
-      Sigma.inv.g <- Sigma.inv[[gg]]
     } else {
-      data.obs.g <- data.obs[[g]]
-      VETA.g <- VETA[[g]]
-      EETA.g <- EETA[[g]]
-      LAMBDA.g <- LAMBDA[[g]]
-      EY.g <- EY[[g]]
-      Sigma.inv.g <- Sigma.inv[[g]]
+      data.obs.g <- data.obs[[b]]
     }
 
-    nfac <- ncol(VETA[[g]])
+    nfac <- ncol(VETA.g)
     if (nfac == 0L) {
       FS[[g]] <- matrix(0, lavdata@nobs[[g]], nfac)
       next
@@ -917,8 +921,7 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
     Yc <- t(t(data.obs.g) - EY.g)
 
     # sampling weights? -- CHECKME: needed??
-    if (.hasSlot(lavdata, "weights") &&
-        !is.null(lavdata@weights[[g]]) && level == 1L) {
+    if (!is.null(lavdata@weights[[g]]) && level == 1L) {
       # EY.g is already weighted
       # use sampling.weights.normalization == "group"
       WT <- lavdata@weights[[g]]
@@ -929,6 +932,11 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
     # global factor score coefficient matrix 'C'
     FSC <- VETA.g %*% t(LAMBDA.g) %*% Sigma.inv.g
 
+    # transform?
+    if (transform) {
+      FSC <- TMAT[[b]] %*% FSC
+    }
+
     # store fsm?
     if (fsm) {
       FSM.g <- FSC
@@ -1047,7 +1055,7 @@ lav_predict_eta_normal <- function(lavobject = NULL, # for convenience
 	}
 
     # standard error
-    if (se == "standard") {
+    if (se == "standard" && !transform) { # for now
       if (lavdata@missing %in% c("ml", "ml.x")) {
         SE[[g]] <- SE.g
         if (acov == "standard") {
@@ -1109,7 +1117,8 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
                                      # optional new data
                                      data.obs = NULL, eXo = NULL,
                                      se = "none", acov = "none", level = 1L,
-                                     fsm = FALSE, rel = FALSE) {
+                                     fsm = FALSE, rel = FALSE,
+                                     transform = FALSE) {
   # full object?
   if (inherits(lavobject, "lavaan")) {
     lavmodel <- lavobject@Model
@@ -1143,12 +1152,12 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
     }
   }
 
-  LAMBDA <- computeLAMBDA(lavmodel = lavmodel, remove.dummy.lv = FALSE)
+  LAMBDA <- lav_model_lambda(lavmodel = lavmodel, remove.dummy.lv = FALSE)
   Sigma.hat <- lavimplied$cov
   Sigma.inv <- lapply(lavimplied$cov, MASS::ginv)
-  VETA <- computeVETA(lavmodel = lavmodel) # for se only
-  EETA <- computeEETA(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
-  EY <- computeEY(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
+  VETA <- lav_model_veta(lavmodel = lavmodel) # for se only
+  EETA <- lav_model_eeta(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
+  EY <- lav_model_ey(lavmodel = lavmodel, lavsamplestats = lavsamplestats)
 
   FS <- vector("list", length = lavdata@ngroups)
   if (fsm) {
@@ -1157,6 +1166,10 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
   if (rel) {
     REL <- vector("list", length = lavdata@ngroups)
   }
+  if (transform) {
+    TMAT <- lav_predict_tmat_det(lavmodel = lavmodel,
+                                 lavimplied = lavimplied)
+  }
 
   if (acov != "none") se <- acov # ACOV implies SE
   if (se != "none") {
@@ -1168,6 +1181,19 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
   }
 
   for (g in 1:lavdata@ngroups) {
+    # determine block
+    if (lavdata@nlevels == 1L) {
+      b <- g
+    } else {
+      b <- (g - 1) * lavdata@nlevels + level
+    }
+
+    VETA.g <- VETA[[b]]
+    EETA.g <- EETA[[b]]
+    LAMBDA.g <- LAMBDA[[b]]
+    EY.g <- EY[[b]]
+    Sigma.inv.g <- Sigma.inv[[b]]
+
     if (lavdata@nlevels > 1L) {
       Lp <- lavdata@Lp[[g]]
       YLp <- lavsamplestats@YLp[[g]]
@@ -1216,23 +1242,11 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
       } else {
         lav_msg_stop(gettext("only 2 levels are supported"))
       }
-
-      gg <- (g - 1) * lavdata@nlevels + level
-      VETA.g <- VETA[[gg]]
-      EETA.g <- EETA[[gg]]
-      LAMBDA.g <- LAMBDA[[gg]]
-      EY.g <- EY[[gg]]
-      Sigma.inv.g <- Sigma.inv[[gg]]
     } else {
-      data.obs.g <- data.obs[[g]]
-      VETA.g <- VETA[[g]]
-      EETA.g <- EETA[[g]]
-      LAMBDA.g <- LAMBDA[[g]]
-      EY.g <- EY[[g]]
-      Sigma.inv.g <- Sigma.inv[[g]]
+      data.obs.g <- data.obs[[b]]
     }
 
-    nfac <- length(EETA[[g]])
+    nfac <- ncol(VETA.g)
     if (nfac == 0L) {
       FS[[g]] <- matrix(0, lavdata@nobs[[g]], nfac)
       next
@@ -1242,8 +1256,7 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
     Yc <- t(t(data.obs.g) - EY.g)
 
     # sampling weights? CHECKME: needed??
-    if (.hasSlot(lavdata, "weights") &&
-        !is.null(lavdata@weights[[g]]) && level == 1L) {
+    if (!is.null(lavdata@weights[[g]]) && level == 1L) {
       # EY.g is already weighted
       # use sampling.weights.normalization == "group"
       WT <- lavdata@weights[[g]]
@@ -1255,6 +1268,11 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
     FSC <- (MASS::ginv(t(LAMBDA.g) %*% Sigma.inv.g %*% LAMBDA.g)
     %*% t(LAMBDA.g) %*% Sigma.inv.g)
 
+    # transform?
+    if (transform) {
+      FSC <- TMAT[[b]] %*% FSC
+    }
+
     # store fsm?
     if (fsm) {
       # store fsm?
@@ -1399,7 +1417,7 @@ lav_predict_eta_bartlett <- function(lavobject = NULL, # for convenience
 	}
 
     # standard error
-    if (se == "standard") {
+    if (se == "standard" && !transform) {
       if (lavdata@missing %in% c("ml", "ml.x")) {
         SE[[g]] <- SE.g
         if (acov == "standard") {
@@ -1490,20 +1508,20 @@ lav_predict_eta_ebm_ml <- function(lavobject = NULL, # for convenience
   #    warning("lavaan WARNING: standard errors are not available (yet) for the non-normal case")
   # }
 
-  VETAx <- computeVETAx(lavmodel = lavmodel)
+  VETAx <- lav_model_vetax(lavmodel = lavmodel)
   VETAx.inv <- VETAx
   for (g in seq_len(lavdata@ngroups)) {
     if (nrow(VETAx[[g]]) > 0L) {
       VETAx.inv[[g]] <- solve(VETAx[[g]])
     }
   }
-  EETAx <- computeEETAx(
+  EETAx <- lav_model_eetax(
     lavmodel = lavmodel, lavsamplestats = lavsamplestats,
     eXo = eXo, nobs = lapply(data.obs, NROW),
     remove.dummy.lv = TRUE
   ) ## FIXME?
-  TH <- computeTH(lavmodel = lavmodel, delta = FALSE)
-  THETA <- computeTHETA(lavmodel = lavmodel)
+  TH <- lav_model_th(lavmodel = lavmodel, delta = FALSE)
+  THETA <- lav_model_theta(lavmodel = lavmodel)
 
   # check for zero entries in THETA (new in 0.6-4)
   for (g in seq_len(lavdata@ngroups)) {
@@ -1735,7 +1753,7 @@ lav_predict_yhat <- function(lavobject = NULL, # for convience
     }
   }
 
-  YHAT <- computeYHAT(
+  YHAT <- lav_model_yhat(
     lavmodel = lavmodel, GLIST = NULL,
     lavsamplestats = lavsamplestats, eXo = eXo,
     nobs = lapply(data.obs, NROW),
@@ -1814,8 +1832,8 @@ lav_predict_fy <- function(lavobject = NULL, # for convience
     duplicate = FALSE, optim.method = optim.method
   )
 
-  THETA <- computeTHETA(lavmodel = lavmodel)
-  TH <- computeTH(lavmodel = lavmodel, delta = FALSE)
+  THETA <- lav_model_theta(lavmodel = lavmodel)
+  TH <- lav_model_th(lavmodel = lavmodel, delta = FALSE)
 
   FY <- vector("list", length = lavdata@ngroups)
   for (g in seq_len(lavdata@ngroups)) {
@@ -1943,7 +1961,7 @@ lav_predict_fy_eta.i <- function(lavmodel = NULL, lavdata = NULL,
 
   # linear predictor for all items
   YHAT <-
-    computeEYetax.LISREL(
+    lav_lisrel_eyetax(
       MLIST = MLIST,
       eXo = x.i,
       ETA = eta.i,
@@ -2016,8 +2034,8 @@ lav_predict_tmat_green <- function(lavobject = NULL,
     lavimplied <- lav_model_implied_cond2uncond(lavimplied)
   }
   Sigma <- lavimplied$cov
-  VETA <- computeVETA(lavmodel = lavmodel, remove.dummy.lv = TRUE)
-  LAMBDA <- computeLAMBDA(lavmodel)
+  VETA <- lav_model_veta(lavmodel = lavmodel, remove.dummy.lv = FALSE)
+  LAMBDA <- lav_model_lambda(lavmodel, remove.dummy.lv = FALSE)
 
   nblocks <- lavmodel@nblocks
   tmat <- vector("list", length = nblocks)
@@ -2055,8 +2073,8 @@ lav_predict_tmat_det <- function(lavobject = NULL,
     lavimplied <- lav_model_implied_cond2uncond(lavimplied)
   }
   Sigma <- lavimplied$cov
-  VETA <- computeVETA(lavmodel = lavmodel, remove.dummy.lv = TRUE)
-  LAMBDA <- computeLAMBDA(lavmodel)
+  VETA <- lav_model_veta(lavmodel = lavmodel, remove.dummy.lv = FALSE)
+  LAMBDA <- lav_model_lambda(lavmodel, remove.dummy.lv = FALSE)
 
   nblocks <- lavmodel@nblocks
   tmat <- vector("list", length = nblocks)
