@@ -5,7 +5,7 @@
 ##
 ## perhaps we should add 0.0005 or something to avoid this?
 
-print.lavaan.data.frame <- function(x, ..., nd = 3L) {
+lav_dataframe_print <- function(x, ..., nd = 3L) {
   ROW.NAMES <- rownames(x)
   y <- as.data.frame(lapply(x, function(x) {
     if (is.numeric(x)) round(x, nd) else x
@@ -25,7 +25,7 @@ print.lavaan.data.frame <- function(x, ..., nd = 3L) {
   invisible(x)
 }
 
-print.lavaan.list <- function(x, ...) {
+lav_lavaanlist_print <- function(x, ...) {
   y <- unclass(x)
   attr(y, "header") <- NULL
 
@@ -45,7 +45,7 @@ print.lavaan.list <- function(x, ...) {
 
 
 # prints only lower triangle of a symmetric matrix
-print.lavaan.matrix.symmetric <- function(x, ..., nd = 3L, shift = 0L,
+lav_matrix_symmetric_print <- function(x, ..., nd = 3L, shift = 0L,
                                           diag.na.dot = TRUE) {
   # print only lower triangle of a symmetric matrix
   # this function was inspired by the `print.correlation' function
@@ -58,7 +58,7 @@ print.lavaan.matrix.symmetric <- function(x, ..., nd = 3L, shift = 0L,
   y[ll] <- format(round(x[ll], digits = nd))
   y[!ll] <- ""
   if (diag.na.dot) {
-    # print a "." instead of NA on the main diagonal (eg summary.efaList)
+    # print a "." instead of NA on the main diagonal (eg lav_efalist_summary)
     diag.idx <- lav_matrix_diag_idx(ncol(x))
     tmp <- x[diag.idx]
     if (all(is.na(tmp))) {
@@ -91,7 +91,7 @@ print.lavaan.matrix.symmetric <- function(x, ..., nd = 3L, shift = 0L,
 }
 
 
-print.lavaan.matrix <- function(x, ..., nd = 3L, shift = 0L) {
+lav_matrix_print <- function(x, ..., nd = 3L, shift = 0L) {
   x <- as.matrix(x) # just in case
   y <- unclass(x)
   attributes(y)[c("header", "footer")] <- NULL
@@ -119,7 +119,7 @@ print.lavaan.matrix <- function(x, ..., nd = 3L, shift = 0L) {
   invisible(x)
 }
 
-print.lavaan.vector <- function(x, ..., nd = 3L, shift = 0L) {
+lav_vector_print <- function(x, ..., nd = 3L, shift = 0L) {
   y <- unclass(x)
   attributes(y)[c("header", "footer")] <- NULL
   # if(!is.null(names(x))) {
@@ -150,7 +150,7 @@ print.lavaan.character <- function(x, ...) {
   invisible(x)
 }
 
-print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
+lav_parameterestimates_print <- function(x, ..., nd = 3L) {
   # format for numeric values
   num.format <- paste("%", max(8L, nd + 5L), ".", nd, "f", sep = "")
   int.format <- paste("%", max(8L, nd + 5L), "d", sep = "")
@@ -608,8 +608,8 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
       b <- b + 1L
 
       # ov/lv names
-      ov.names <- lavNames(x, "ov", block = b)
-      lv.names <- lavNames(x, "lv", block = b)
+      ov.names <- lav_object_vnames(x, "ov", block = b)
+      lv.names <- lav_object_vnames(x, "lv", block = b)
 
       # level header
       if (nlevels > 1L) {
@@ -624,50 +624,50 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
           row.idx <- which(x$op == "=~" & !x$lhs %in% ov.names &
             x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "Composites") {
           row.idx <- which(x$op == "<~" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "Regressions") {
           row.idx <- which(x$op == "~" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "Covariances") {
           row.idx <- which(x$op == "~~" & x$lhs != x$rhs & !x$exo &
             x$block == b)
           if (length(row.idx) == 0L) next
           # make distinction between residual and plain
           y.names <- unique(c(
-            lavNames(x, "eqs.y"),
-            lavNames(x, "ov.ind"),
-            lavNames(x, "lv.ind")
+            lav_object_vnames(x, "eqs.y"),
+            lav_object_vnames(x, "ov.ind"),
+            lav_object_vnames(x, "lv.ind")
           ))
           PREFIX <- rep("", length(row.idx))
           PREFIX[x$rhs[row.idx] %in% y.names] <- "  ."
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx],
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx],
             PREFIX = PREFIX
           )
-          # m[row.idx,1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          # m[row.idx,1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "Intercepts") {
           row.idx <- which(x$op == "~1" & !x$exo & x$block == b)
           if (length(row.idx) == 0L) next
           # make distinction between intercepts and means
           y.names <- unique(c(
-            lavNames(x, "eqs.y"),
-            lavNames(x, "ov.ind"),
-            lavNames(x, "lv.ind")
+            lav_object_vnames(x, "eqs.y"),
+            lav_object_vnames(x, "ov.ind"),
+            lav_object_vnames(x, "lv.ind")
           ))
           PREFIX <- rep("", length(row.idx))
           PREFIX[x$lhs[row.idx] %in% y.names] <- "  ."
-          m[row.idx, 1] <- .makeNames(x$lhs[row.idx], x$label[row.idx],
+          m[row.idx, 1] <- lav_print_format_names(x$lhs[row.idx], x$label[row.idx],
             PREFIX = PREFIX
           )
-          # m[row.idx,1] <- .makeNames(x$lhs[row.idx], x$label[row.idx])
+          # m[row.idx,1] <- lav_print_format_names(x$lhs[row.idx], x$label[row.idx])
         } else if (s == "Thresholds") {
           row.idx <- which(x$op == "|" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(paste(x$lhs[row.idx], "|",
+          m[row.idx, 1] <- lav_print_format_names(paste(x$lhs[row.idx], "|",
             x$rhs[row.idx],
             sep = ""
           ), x$label[row.idx])
@@ -677,27 +677,27 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
           if (length(row.idx) == 0L) next
           # make distinction between residual and plain
           y.names <- unique(c(
-            lavNames(x, "eqs.y"),
-            lavNames(x, "ov.ind"),
-            lavNames(x, "lv.ind")
+            lav_object_vnames(x, "eqs.y"),
+            lav_object_vnames(x, "ov.ind"),
+            lav_object_vnames(x, "lv.ind")
           ))
           PREFIX <- rep("", length(row.idx))
           PREFIX[x$rhs[row.idx] %in% y.names] <- "  ."
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx],
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx],
             PREFIX = PREFIX
           )
         } else if (s == "Scales y*") {
           row.idx <- which(x$op == "~*~" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "Group Weight") {
           row.idx <- which(x$lhs == "group" & x$op == "%" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else if (s == "R-Square") {
           row.idx <- which(x$op == "r2" & x$block == b)
           if (length(row.idx) == 0L) next
-          m[row.idx, 1] <- .makeNames(x$rhs[row.idx], x$label[row.idx])
+          m[row.idx, 1] <- lav_print_format_names(x$rhs[row.idx], x$label[row.idx])
         } else {
           row.idx <- integer(0L)
         }
@@ -732,9 +732,9 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
           if (s == "Covariances") {
             # make distinction between residual and plain
             y.names <- unique(c(
-              lavNames(x, "eqs.y"),
-              lavNames(x, "ov.ind"),
-              lavNames(x, "lv.ind")
+              lav_object_vnames(x, "eqs.y"),
+              lav_object_vnames(x, "ov.ind"),
+              lav_object_vnames(x, "lv.ind")
             ))
             PREFIX <- rep("", length(row.idx))
             PREFIX[x$lhs[row.idx] %in% y.names] <- "."
@@ -791,13 +791,13 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
   for (s in ASECTIONS) {
     if (s == "Defined Parameters") {
       row.idx <- which(x$op == ":=")
-      m[row.idx, 1] <- .makeNames(x$lhs[row.idx], "")
+      m[row.idx, 1] <- lav_print_format_names(x$lhs[row.idx], "")
       M <- m[row.idx, , drop = FALSE]
       colnames(M) <- colnames(m)
     } else if (s == "Constraints") {
       row.idx <- which(x$op %in% c("==", "<", ">"))
       if (length(row.idx) == 0) next
-      m[row.idx, 1] <- .makeConNames(x$lhs[row.idx], x$op[row.idx],
+      m[row.idx, 1] <- lav_print_format_constraints(x$lhs[row.idx], x$op[row.idx],
         x$rhs[row.idx],
         nd = nd
       )
@@ -823,7 +823,7 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
   invisible(m)
 }
 
-.makeNames <- function(NAMES, LABELS, PREFIX = NULL) {
+lav_print_format_names <- function(NAMES, LABELS, PREFIX = NULL) {
   W <- 14
   if (is.null(PREFIX)) {
     PREFIX <- rep("", length(NAMES))
@@ -866,7 +866,7 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
   sprintf(char.format, PREFIX, NAMES)
 }
 
-.makeConNames <- function(lhs, op, rhs, nd) {
+lav_print_format_constraints <- function(lhs, op, rhs, nd) {
   nd <- max(nd, 3)
   W <- 41 + (nd - 3) * 3
 
@@ -897,7 +897,7 @@ print.lavaan.parameterEstimates <- function(x, ..., nd = 3L) {
   NAMES
 }
 
-summary.lavaan.fsr <- function(object, ...) {
+lav_fsr_summary <- function(object, ...) {
   dotdotdot <- list(...)
   if (!is.null(dotdotdot$nd)) {
     nd <- dotdotdot$nd
@@ -905,10 +905,10 @@ summary.lavaan.fsr <- function(object, ...) {
     nd <- 3L
   }
 
-  print.lavaan.fsr(x = object, nd = nd, mm = TRUE, struc = TRUE)
+  lav_fsr_print(x = object, nd = nd, mm = TRUE, struc = TRUE)
 }
 
-print.lavaan.fsr <- function(x, ..., nd = 3L, mm = FALSE, struc = FALSE) {
+lav_fsr_print <- function(x, ..., nd = 3L, mm = FALSE, struc = FALSE) {
   y <- unclass(x)
 
   # print header
@@ -923,7 +923,7 @@ print.lavaan.fsr <- function(x, ..., nd = 3L, mm = FALSE, struc = FALSE) {
     for (b in seq_len(nblocks)) {
       cat(
         "Measurement block for latent variable(s):",
-        paste(lavNames(y$MM.FIT[[b]], "lv")), "\n"
+        paste(lav_object_vnames(y$MM.FIT[[b]], "lv")), "\n"
       )
 
       # fit measures?
@@ -934,11 +934,11 @@ print.lavaan.fsr <- function(x, ..., nd = 3L, mm = FALSE, struc = FALSE) {
       }
 
       # parameter estimates
-      PE <- parameterEstimates(y$MM.FIT[[b]],
+      PE <- lavParameterEstimates(y$MM.FIT[[b]],
         ci = FALSE,
         output = "text", header = TRUE
       )
-      print.lavaan.parameterEstimates(PE, ..., nd = nd)
+      lav_parameterestimates_print(PE, ..., nd = nd)
       cat("\n")
     }
   }
@@ -953,23 +953,23 @@ print.lavaan.fsr <- function(x, ..., nd = 3L, mm = FALSE, struc = FALSE) {
     ))
     FIT <- fitMeasures(y$STRUC.FIT, fit.measures = "default")
     if (FIT["df"] > 0) {
-      print.lavaan.fitMeasures(FIT, add.h0 = FALSE)
+      lav_fitmeasures_print(FIT, add.h0 = FALSE)
     }
   }
-  PE <- parameterEstimates(y$STRUC.FIT,
+  PE <- lavParameterEstimates(y$STRUC.FIT,
     ci = FALSE,
     remove.eq = FALSE, remove.system.eq = TRUE,
     remove.ineq = FALSE, remove.def = FALSE,
     remove.nonfree = FALSE, remove.unused = TRUE,
     output = "text", header = TRUE
   )
-  print.lavaan.parameterEstimates(PE, ..., nd = nd)
+  lav_parameterestimates_print(PE, ..., nd = nd)
 
   invisible(y)
 }
 
 # new in 0.6-12
-print.lavaan.summary <- function(x, ..., nd = 3L) {
+lav_summary_print <- function(x, ..., nd = 3L) {
   y <- unclass(x) # change to ordinary list
 
   # get nd, if it is stored as an attribute
@@ -1332,7 +1332,7 @@ print.lavaan.summary <- function(x, ..., nd = 3L) {
     if (!is.null(attr(y$fit, "add.h0"))) {
       add.h0 <- isTRUE(attr(y$fit, "add.h0"))
     }
-    print.lavaan.fitMeasures(y$fit, nd = nd, add.h0 = add.h0)
+    lav_fitmeasures_print(y$fit, nd = nd, add.h0 = add.h0)
   }
 
   # efa output
