@@ -386,6 +386,7 @@ lav_sam_veta2 <- function(FS = NULL, M = NULL,
                           dummy.lv.names = character(0L),
                           alpha.correction = 0L,
                           lambda.correction = TRUE,
+                          fs.outlier.idx = integer(0L),
                           return.FS = FALSE,
                           return.cov.iveta2 = TRUE,
                           extra = FALSE) {
@@ -505,7 +506,7 @@ lav_sam_veta2 <- function(FS = NULL, M = NULL,
 	  cutoff <- 1 + 2/N # be more conservative for VETA2
       if (lambda < cutoff) {
         #lambda.star <- lambda - 1 / (N - 1)
-		lambda.star <- max(c(0, lambda - 2/N))
+		lambda.star <- max(c(0, lambda - ncol(Var.FS2)/(N - 1)))
         VETA2 <- Var.FS2 - lambda.star * Var.ERROR
       } else {
         VETA2 <- Var.FS2 - Var.ERROR
@@ -538,6 +539,12 @@ lav_sam_veta2 <- function(FS = NULL, M = NULL,
       IVETA2[i,] <- c(ieeta2[lv.keep],
                       lav_matrix_vech(iveta2[lv.keep, lv.keep]))
     } # N
+    # experimental:
+    # remove outliers in FS?
+    #if (length(fs.outlier.idx) > 0L) {
+    #  IVETA2 <- IVETA2[-fs.outlier.idx, ,drop = FALSE]
+    #  N <- N - length(fs.outlier.idx)
+    #}
     cov.iveta2 <- cov(IVETA2) * (N-1)/N
   }
 
@@ -910,7 +917,7 @@ lav_sam_get_mmlist <- function(lavobject) {
     }
 
     # cluster membership
-    membership <- lav_utils_get_connected_nodes(CC)
+    membership <- lav_graph_get_connected_nodes(CC)
 
     out <- split(NAMES, NAMES[membership])
     names(out) <- paste("block", seq_len(length(out)), sep = "")
