@@ -164,7 +164,7 @@ lav_samplestats_from_data <- function(lavdata = NULL,
   if (is.null(NACOV)) {
     NACOV <- vector("list", length = ngroups)
     NACOV.user <- FALSE
-    if (se == "robust.sem" && missing == "listwise") {
+    if (se %in% c("robust.sem", "robust.sem.nt") && missing == "listwise") {
       NACOV.compute <- TRUE
     }
     # note: test can be a vector...
@@ -275,9 +275,7 @@ lav_samplestats_from_data <- function(lavdata = NULL,
 
       if (estimator %in% c("ML", "REML", "PML", "FML", "MML", "none", "ULS")) {
         WLS.W <- FALSE
-        if (estimator == "ULS" && se == "robust.sem") { #||
-          # any(test %in% c("satorra.bentler", "scaled.shifted",
-          #            "mean.var.adjusted")))) {
+        if (estimator == "ULS" && se %in% c("robust.sem", "robust.sem.nt")) {
           WLS.W <- TRUE
         }
       } else {
@@ -869,21 +867,34 @@ lav_samplestats_from_data <- function(lavdata = NULL,
               meanstructure = meanstructure
             )
 		  } else {
-            NACOV[[g]] <-
-              lav_samplestats_Gamma(
-                Y = Y,
-                x.idx = x.idx[[g]],
-                cluster.idx = cluster.idx,
-                fixed.x = fixed.x,
-                conditional.x = conditional.x,
-                meanstructure = meanstructure,
-                slopestructure = conditional.x,
-                gamma.n.minus.one =
-                  lavoptions$gamma.n.minus.one,
-                unbiased =
-                  lavoptions$gamma.unbiased,
-                Mplus.WLS = (mimic == "Mplus")
-              )
+            if (lavoptions$se == "robust.sem.nt") {
+              NACOV[[g]] <-
+                lav_samplestats_Gamma_NT(
+                  Y = Y,
+                  x.idx = x.idx[[g]],
+                  # cluster.idx = cluster.idx, # not available
+                  fixed.x = fixed.x,
+                  conditional.x = conditional.x,
+                  meanstructure = meanstructure,
+                  slopestructure = conditional.x
+                )
+            } else {
+              NACOV[[g]] <-
+                lav_samplestats_Gamma(
+                  Y = Y,
+                  x.idx = x.idx[[g]],
+                  cluster.idx = cluster.idx,
+                  fixed.x = fixed.x,
+                  conditional.x = conditional.x,
+                  meanstructure = meanstructure,
+                  slopestructure = conditional.x,
+                  gamma.n.minus.one =
+                    lavoptions$gamma.n.minus.one,
+                  unbiased =
+                    lavoptions$gamma.unbiased,
+                  Mplus.WLS = lavoptions$gamma.wls.mplus
+                )
+            }
           }
         } else { # categorical case
           NACOV[[g]] <- CAT$WLS.W * nobs[[g]]
@@ -975,7 +986,7 @@ lav_samplestats_from_data <- function(lavdata = NULL,
             slopestructure = conditional.x
           )
         }
-        if (mimic == "Mplus" && !conditional.x && meanstructure) {
+        if (lavoptions$gls.v11.mplus && !conditional.x && meanstructure) {
           # bug in Mplus? V11 rescaled by nobs[[g]]/(nobs[[g]]-1)
           nvar <- NCOL(cov[[g]])
           WLS.V[[g]][1:nvar, 1:nvar] <-
@@ -1056,7 +1067,12 @@ lav_samplestats_from_data <- function(lavdata = NULL,
           }
         } else {
           if (estimator == "WLS") {
-            WLS.V[[g]] <- inv.chol(CAT$WLS.W * nobs[[g]])
+            cS <- tryCatch(chol(CAT$WLS.W * nobs[[g]]),
+                           error = function(e) NULL)
+            if (is.null(cS)) {
+              lav_msg_stop(gettext("could not invert CAT$WLS.W"))
+            }
+            WLS.V[[g]] <- chol2inv(cS)
           } else if (estimator == "DWLS") {
             dacov <- diag(CAT$WLS.W * nobs[[g]])
             # WLS.V[[g]] <- diag(1/dacov, nrow=NROW(CAT$WLS.W),
@@ -1262,7 +1278,7 @@ lav_samplestats_from_moments <- function(sample.cov = NULL,
     if (!is.list(sample.mean)) {
       # check if sample.mean is string (between single quotes)
       if (is.character(sample.mean)) {
-        sample.mean <- char2num(sample.mean)
+        sample.mean <- lav_char2num(sample.mean)
       }
       sample.mean <- list(unname(sample.mean))
     } else {
