@@ -12,7 +12,6 @@ lav_start <- function(start.method = "default",
                       lavsamplestats = NULL,
                       lavh1 = NULL, # fixme: only use lavh1?
                       model.type = "sem",
-                      mimic = "lavaan",
                       reflect = FALSE, # rotation only
 					            samplestats.flag = TRUE,
                       order.lv.by = "none" # rotation only
@@ -46,14 +45,14 @@ lav_start <- function(start.method = "default",
   }
 
   # check start.method
-  if (mimic == "lavaan") {
-    start.initial <- "lavaan"
-  } else if (mimic == "Mplus") {
-    start.initial <- "mplus"
-  } else {
-    # FIXME: use LISREL/EQS/AMOS/.... schemes
-    start.initial <- "lavaan"
-  }
+  #if (mimic == "lavaan") {
+  start.initial <- "lavaan"
+  #} else if (mimic == "Mplus") {
+  #  start.initial <- "mplus"
+  #} else {
+  #  # FIXME: use LISREL/EQS/AMOS/.... schemes
+  #  start.initial <- "lavaan"
+  #}
 
   # start.method
   start.user <- NULL
@@ -73,7 +72,7 @@ lav_start <- function(start.method = "default",
       #    start[ which(lavpartable$op == "=~") ] <- 1.0
       # }
       start[which(lavpartable$op == "~*~")] <- 1.0
-      ov.names.ord <- vnames(lavpartable, "ov.ord")
+      ov.names.ord <- lav_partable_vnames(lavpartable, "ov.ord")
       var.idx <- which(lavpartable$op == "~~" &
         lavpartable$lhs == lavpartable$rhs &
         !(lavpartable$lhs %in% ov.names.ord))
@@ -83,7 +82,7 @@ lav_start <- function(start.method = "default",
       return(start) # assuming fixed.x = FALSE!
     } else if (start.method == "est") {
       return(lavpartable$est)
-    } else if (start.method.lc %in% c("simple", "lavaan", "mplus")) {
+    } else if (start.method.lc %in% c("simple", "lavaan")) {
       start.initial <- start.method.lc
     } else {
      lav_msg_stop(gettext("unknown value for start argument"))
@@ -140,7 +139,7 @@ lav_start <- function(start.method = "default",
   }
 
   # 2. (residual) lv variances for latent variables
-  lv.names <- vnames(lavpartable, "lv") # all groups
+  lv.names <- lav_partable_vnames(lavpartable, "lv") # all groups
   lv.var.idx <- which(lavpartable$op == "~~" &
     lavpartable$lhs %in% lv.names &
     lavpartable$lhs == lavpartable$rhs)
@@ -162,28 +161,28 @@ lav_start <- function(start.method = "default",
     lavpartable$group[lavpartable$block == 0L] <- 0L
   }
 
+  # group values
+  group.values <- lav_partable_group_values(lavpartable)
 
   for (g in 1:ngroups) {
-    # group values (not necessarily 1,2,... anymore)
-    group.values <- lav_partable_group_values(lavpartable)
 
     # info from user model for this group
     if (conditional.x) {
-      ov.names <- vnames(lavpartable, "ov.nox", group = group.values[g])
+      ov.names <- lav_partable_vnames(lavpartable, "ov.nox", group = group.values[g])
     } else {
-      ov.names <- vnames(lavpartable, "ov", group = group.values[g])
+      ov.names <- lav_partable_vnames(lavpartable, "ov", group = group.values[g])
     }
     if (categorical) {
-      ov.names.num <- vnames(lavpartable, "ov.num", group = group.values[g])
-      ov.names.ord <- vnames(lavpartable, "ov.ord", group = group.values[g])
+      ov.names.num <- lav_partable_vnames(lavpartable, "ov.num", group = group.values[g])
+      ov.names.ord <- lav_partable_vnames(lavpartable, "ov.ord", group = group.values[g])
     } else {
       ov.names.num <- ov.names
     }
-    lv.names <- vnames(lavpartable, "lv", group = group.values[g])
-    lv.names.efa <- vnames(lavpartable, "lv.efa", group = group.values[g])
-    ov.names.x <- vnames(lavpartable, "ov.x", group = group.values[g])
-    ov.ind.c <- vnames(lavpartable, "ov.cind", group = group.values[g])
-    lv.names.c <- vnames(lavpartable, "lv.composite", group = group.values[g])
+    lv.names <- lav_partable_vnames(lavpartable, "lv", group = group.values[g])
+    lv.names.efa <- lav_partable_vnames(lavpartable, "lv.efa", group = group.values[g])
+    ov.names.x <- lav_partable_vnames(lavpartable, "ov.x", group = group.values[g])
+    ov.ind.c <- lav_partable_vnames(lavpartable, "ov.cind", group = group.values[g])
+    lv.names.c <- lav_partable_vnames(lavpartable, "lv.composite", group = group.values[g])
 
     # just for the nlevels >1 case
     ov.names <- unique(unlist(ov.names))
@@ -212,15 +211,15 @@ lav_start <- function(start.method = "default",
       }
       start[ov.var.idx] <- diag(h1.cov)[sample.var.idx]
     } else {
-      if (start.initial == "mplus") {
-        if (conditional.x && nlevels == 1L) {
-          start[ov.var.idx] <-
-            (1.0 - 0.50) * lavsamplestats@res.var[[1L]][sample.var.idx]
-        } else {
-          start[ov.var.idx] <-
-            (1.0 - 0.50) * lavsamplestats@var[[1L]][sample.var.idx]
-        }
-      } else {
+      #if (start.initial == "mplus") {
+      #  if (conditional.x && nlevels == 1L) {
+      #    start[ov.var.idx] <-
+      #      (1.0 - 0.50) * lavsamplestats@res.var[[1L]][sample.var.idx]
+      #  } else {
+      #    start[ov.var.idx] <-
+      #      (1.0 - 0.50) * lavsamplestats@var[[1L]][sample.var.idx]
+      #  }
+      #} else {
         if (conditional.x && nlevels == 1L) {
           start[ov.var.idx] <-
             (1.0 - 0.50) * diag(lavsamplestats@res.cov[[g]])[sample.var.idx]
@@ -228,7 +227,7 @@ lav_start <- function(start.method = "default",
           start[ov.var.idx] <-
             (1.0 - 0.50) * diag(lavsamplestats@cov[[g]])[sample.var.idx]
         }
-      }
+      #}
       # composite indicators: fill in total variances
       if (composites) {
         start[ov.var.idx] <- diag(lavsamplestats@cov[[g]])[sample.var.idx]
@@ -236,7 +235,7 @@ lav_start <- function(start.method = "default",
     }
 
     # 1-fac measurement models: loadings, psi, theta
-    if (start.initial %in% c("lavaan", "mplus") &&
+    if (start.initial %in% c("lavaan") &&
       model.type %in% c("sem", "cfa")) {
       # fabin3 estimator (2sls) of Hagglund (1982) per factor
       for (f in lv.names.noc) {
@@ -533,7 +532,7 @@ lav_start <- function(start.method = "default",
       th.names.sample <-
         lavsamplestats@th.names[[g]][lavsamplestats@th.idx[[g]] > 0L]
       # th.names.sample should identical to
-      # vnames(lavpartable, "th", group = group.values[g])
+      # lav_partable_vnames(lavpartable, "th", group = group.values[g])
       if (conditional.x && nlevels == 1L) {
         th.values <-
           lavsamplestats@res.th[[g]][lavsamplestats@th.idx[[g]] > 0L]
@@ -593,7 +592,7 @@ lav_start <- function(start.method = "default",
     }
 
     # 6b. exogenous lv variances if single indicator -- new in 0.5-21
-    lv.x <- vnames(lavpartable, "lv.x", group = group.values[g])
+    lv.x <- lav_partable_vnames(lavpartable, "lv.x", group = group.values[g])
     # FIXME: also for multilevel?
     lv.x <- unique(unlist(lv.x))
     if (length(lv.x) > 0L) {
@@ -691,8 +690,8 @@ lav_start <- function(start.method = "default",
     }
 
     #  # 8 latent variances (new in 0.6-2)
-    #  lv.names.y <- vnames(lavpartable, "lv.y", group = group.values[g])
-    #  lv.names.x <- vnames(lavpartable, "lv.x", group = group.values[g])
+    #  lv.names.y <- lav_partable_vnames(lavpartable, "lv.y", group = group.values[g])
+    #  lv.names.x <- lav_partable_vnames(lavpartable, "lv.x", group = group.values[g])
     #  # multilevel? take first level only
     #  if(is.list(lv.names.y)) {
     #      lv.names.y <- unlist(lv.names.y) # for now
@@ -917,7 +916,7 @@ lav_start <- function(start.method = "default",
   # growth models:
   # - compute starting values for mean latent variables
   # - compute starting values for variance latent variables
-  if (start.initial %in% c("lavaan", "mplus") &&
+  if (start.initial %in% c("lavaan") &&
     model.type == "growth") {
     ### DEBUG ONLY
     # lv.var.idx <- which(lavpartable$op == "~~"                &
@@ -984,6 +983,27 @@ lav_start <- function(start.method = "default",
   user.idx <- which(!is.na(lavpartable$ustart) & lavpartable$free == 0L)
   start[user.idx] <- lavpartable$ustart[user.idx]
 
+  # new in 0.6-21
+  # if any thresholds, make sure they are in increasing order
+  # (could be an issue if the first and second were fixed to 0 and 1)
+  for (g in 1:ngroups) {
+    th.idx <- which(lavpartable$group == group.values[g] &
+                    lavpartable$op == "|")
+    if (length(th.idx) > 0L) {
+      # for every ov.ord, check if t1 < t2 < t3 < ...
+      ov.ord <- unique(lavpartable$lhs[th.idx])
+      for (oo in ov.ord) {
+        this.idx <- which(lavpartable$group == group.values[g] &
+                          lavpartable$op == "|" & lavpartable$lhs == oo)
+        item.th <- start[this.idx]
+        if (length(item.th) > 1L && !all(diff(item.th) > 0)) {
+          start[this.idx] <- cumsum(abs(item.th))
+        }
+      }
+    }
+  }
+
+
   # final check: no NaN or other non-finite values
   bad.idx <- which(!is.finite(start))
   if (length(bad.idx) > 0L) {
