@@ -49,6 +49,10 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
   } else {
     logical(0L)
   }
+  # check object
+  object <- lav_object_check_version(object)
+  # check models in dots
+  dots[modp] <- lapply(dots[modp], lav_object_check_version)
 
   # some general properties (taken from the first model)
   estimator <- object@Options$estimator
@@ -96,7 +100,7 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
   if (TRUE) {
     # 1. same set of observed variables?
     ov.names <- lapply(mods, function(x) {
-      sort(lavNames(x))
+      sort(lav_object_vnames(x))
     })
     OV <- ov.names[[1L]] # the observed variable names of the first model
     if (!all(sapply(ov.names, function(x) identical(x, OV)))) {
@@ -113,7 +117,7 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
     # TODO!
 
     # 3. all meanstructure?
-    mean.structure <- sapply(mods, inspect, "meanstructure")
+    mean.structure <- sapply(mods, lavInspect, "meanstructure")
     if (sum(mean.structure) > 0L &&
       sum(mean.structure) < length(mean.structure)) {
       lav_msg_warn(gettext("not all models have a meanstructure"))
@@ -318,7 +322,7 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
       }
     } else if (method == "mean.var.adjusted.PLRT") {
       for (m in seq_len(length(mods) - 1L)) {
-        out <- ctr_pml_plrt_nested(mods[[m]], mods[[m + 1]])
+        out <- lav_pml_test_plrt(mods[[m]], mods[[m + 1]])
         STAT.delta[m + 1] <- out$FSMA.PLRT
         Df.delta[m + 1] <- out$adj.df
       }
@@ -375,6 +379,8 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
 
   # unname
   STAT.delta <- unname(STAT.delta)
+  # zap small values (for near-zero values) (anova class does not use rounding)
+  STAT.delta <- round(STAT.delta, 10)
   Df.delta <- unname(Df.delta)
   STAT.delta.orig <- unname(STAT.delta.orig)
   Df.delta.orig <- unname(Df.delta.orig)
@@ -407,7 +413,7 @@ lavTestLRT <- function(object, ..., method = "default", test = "default",
     aic <- sapply(mods, FUN = AIC)
     bic <- sapply(mods, FUN = BIC)
   } else if (estimator == "PML") {
-    OUT <- lapply(mods, ctr_pml_aic_bic)
+    OUT <- lapply(mods, lav_pml_object_aic_bic)
     aic <- sapply(OUT, "[[", "PL_AIC")
     bic <- sapply(OUT, "[[", "PL_BIC")
   }
